@@ -5,12 +5,12 @@ var k=!1;try{h.hasOwnProperty("responseType")&&(h.responseType="arraybuffer",k=!
 h.responseText:null}catch(k){}try{g.binary=h.response}catch(l){}try{f=h.statusText}catch(t){f=""}!b&&a.isLocal&&!a.crossDomain?b=g.text?200:404:1223===b&&(b=204);m(b,f,g,c)}}catch(s){alert(s),m(-1,s)}};a.async?4===h.readyState?setTimeout(d):h.onreadystatechange=d:d()},abort:function(){}}}))})(jQuery);
 (function(a,h,e,d){function g(e,g){function k(b){a(l).each(function(){self.Jmol&&(0<=g.indexOf("mouseup")||0<=g.indexOf("touchend"))&&Jmol._setMouseOwner(null);var c=a(this);this!==b.target&&!c.has(b.target).length&&c.triggerHandler(g,[b.target,b])})}g=g||e+d;var l=a(),b=e+"."+g+"-special-event";a.event.special[g]={setup:function(){l=l.add(this);1===l.length&&a(h).bind(b,k)},teardown:function(){self.Jmol&&Jmol._setMouseOwner(null);l=l.not(this);0===l.length&&a(h).unbind(b)},add:function(b){var a=
 b.handler;b.handler=function(b,f){b.target=f;a.apply(this,arguments)}}}}a.map(e.split(" "),function(a){g(a)});g("focusin","focus"+d);g("focusout","blur"+d)})(jQuery,document,"click mousemove mouseup touchmove touchend","outjsmol");"undefined"==typeof jQuery&&alert("Note -- JSmoljQuery is required for JSmol, but it's not defined.");self.Jmol||(Jmol={});
-Jmol._version||(Jmol=function(a){var h=function(a){return{rear:a++,header:a++,main:a++,image:a++,front:a++,fileOpener:a++,coverImage:a++,dialog:a++,menu:a+9E4,console:a+91E3,consoleImage:a+91001,monitorZIndex:a+99999}},h={_version:"$Date: 2016-02-14 19:46:51 -0600 (Sun, 14 Feb 2016) $",_alertNoBinary:!0,_allowedJmolSize:[25,2048,300],_appletCssClass:"",_appletCssText:"",_fileCache:null,_jarFile:null,_j2sPath:null,_use:null,_j2sLoadMonitorOpacity:90,_applets:{},_asynchronous:!0,_ajaxQueue:[],_persistentMenu:!1,
-_getZOrders:h,_z:h(Jmol.z||9E3),_debugCode:!0,db:{_databasePrefixes:"$=:",_fileLoadScript:";if (_loadScript = '' && defaultLoadScript == '' && _filetype == 'Pdb') { select protein or nucleic;cartoons Only;color structure; select * };",_nciLoadScript:";n = ({molecule=1}.length < {molecule=2}.length ? 2 : 1); select molecule=n;display selected;center selected;",_pubChemLoadScript:"",_DirectDatabaseCalls:{"cactus.nci.nih.gov":null,"rruff.geo.arizona.edu":null,"www.rcsb.org":null,"cdn.rcsb.org":null,
-"ftp.wwpdb.org":null,"pdbe.org":null,"www.ebi.ac.uk":null,"wwwdev.ebi.ac.uk":null,"pubchem.ncbi.nlm.nih.gov":null,"http://www.nmrdb.org/tools/jmol/predict.php":null,$:"http://cactus.nci.nih.gov/chemical/structure/%FILENCI/file?format=sdf&get3d=True",$$:"http://cactus.nci.nih.gov/chemical/structure/%FILENCI/file?format=sdf","=":"http://www.rcsb.org/pdb/files/%FILE.pdb","*":"http://www.ebi.ac.uk/pdbe/entry-files/download/%FILE.cif","==":"http://www.rcsb.org/pdb/files/ligand/%FILE.cif",":":"http://pubchem.ncbi.nlm.nih.gov/rest/pug/compound/%FILE/SDF?record_type=3d"},
-_restQueryUrl:"http://www.rcsb.org/pdb/rest/search",_restQueryXml:"<orgPdbQuery><queryType>org.pdb.query.simple.AdvancedKeywordQuery</queryType><description>Text Search</description><keywords>QUERY</keywords></orgPdbQuery>",_restReportUrl:"http://www.pdb.org/pdb/rest/customReport?pdbids=IDLIST&customReportColumns=structureId,structureTitle"},_debugAlert:!1,_document:a,_isXHTML:!1,_lastAppletID:null,_mousePageX:null,_mouseOwner:null,_serverUrl:"http://your.server.here/jsmol.php",_syncId:(""+Math.random()).substring(3),
-_touching:!1,_XhtmlElement:null,_XhtmlAppendChild:!1};a=a.location.href.toLowerCase();h._httpProto=0==a.indexOf("https")?"https://":"http://";h._isFile=0==a.indexOf("file:");h._isFile&&$.ajaxSetup({mimeType:"text/plain"});h._ajaxTestSite=h._httpProto+"google.com";a=h._isFile||0==a.indexOf("http://localhost")||0==a.indexOf("http://127.");h._tracker="http://"==h._httpProto&&!a&&"http://chemapps.stolaf.edu/jmol/JmolTracker.htm?id=UA-45940799-1";h._isChrome=0<=navigator.userAgent.toLowerCase().indexOf("chrome");
-h._isSafari=!h._isChrome&&0<=navigator.userAgent.toLowerCase().indexOf("safari");h._isMsie=void 0!==window.ActiveXObject;h._isEdge=0<=navigator.userAgent.indexOf("Edge/");h._useDataURI=!h._isSafari&&!h._isMsie&&!h._isEdge;window.requestAnimationFrame||(window.requestAnimationFrame=window.setTimeout);for(var e in Jmol)h[e]=Jmol[e];return h}(document,Jmol));
+Jmol._version||(Jmol=function(a){var h=function(a){return{rear:a++,header:a++,main:a++,image:a++,front:a++,fileOpener:a++,coverImage:a++,dialog:a++,menu:a+9E4,console:a+91E3,consoleImage:a+91001,monitorZIndex:a+99999}},h={_version:"$Date: 2016-03-24 16:58:21 -0500 (Thu, 24 Mar 2016) $",_alertNoBinary:!0,_allowedJmolSize:[25,2048,300],_appletCssClass:"",_appletCssText:"",_fileCache:null,_jarFile:null,_j2sPath:null,_use:null,_j2sLoadMonitorOpacity:90,_applets:{},_asynchronous:!0,_ajaxQueue:[],_persistentMenu:!1,
+_getZOrders:h,_z:h(Jmol.z||9E3),_debugCode:!0,db:{_databasePrefixes:"$=:",_fileLoadScript:";if (_loadScript = '' && defaultLoadScript == '' && _filetype == 'Pdb') { select protein or nucleic;cartoons Only;color structure; select * };",_nciLoadScript:";n = ({molecule=1}.length < {molecule=2}.length ? 2 : 1); select molecule=n;display selected;center selected;",_pubChemLoadScript:"",_DirectDatabaseCalls:{"cactus.nci.nih.gov":null,"rruff.geo.arizona.edu":null,"files.rcsb.org":null,"www.rcsb.org":null,
+"cdn.rcsb.org":null,"ftp.wwpdb.org":null,"pdbe.org":null,"www.ebi.ac.uk":null,"wwwdev.ebi.ac.uk":null,"pubchem.ncbi.nlm.nih.gov":null,"http://www.nmrdb.org/tools/jmol/predict.php":null,$:"http://cactus.nci.nih.gov/chemical/structure/%FILENCI/file?format=sdf&get3d=True",$$:"http://cactus.nci.nih.gov/chemical/structure/%FILENCI/file?format=sdf","=":"http://files.rcsb.org/view/%FILE.pdb","*":"http://www.ebi.ac.uk/pdbe/entry-files/download/%FILE.cif","==":"http://www.rcsb.org/pdb/files/ligand/%FILE.cif",
+":":"http://pubchem.ncbi.nlm.nih.gov/rest/pug/compound/%FILE/SDF?record_type=3d"},_restQueryUrl:"http://www.rcsb.org/pdb/rest/search",_restQueryXml:"<orgPdbQuery><queryType>org.pdb.query.simple.AdvancedKeywordQuery</queryType><description>Text Search</description><keywords>QUERY</keywords></orgPdbQuery>",_restReportUrl:"http://www.pdb.org/pdb/rest/customReport?pdbids=IDLIST&customReportColumns=structureId,structureTitle"},_debugAlert:!1,_document:a,_isXHTML:!1,_lastAppletID:null,_mousePageX:null,
+_mouseOwner:null,_serverUrl:"http://your.server.here/jsmol.php",_syncId:(""+Math.random()).substring(3),_touching:!1,_XhtmlElement:null,_XhtmlAppendChild:!1};a=a.location.href.toLowerCase();h._httpProto=0==a.indexOf("https")?"https://":"http://";h._isFile=0==a.indexOf("file:");h._isFile&&$.ajaxSetup({mimeType:"text/plain"});h._ajaxTestSite=h._httpProto+"google.com";a=h._isFile||0==a.indexOf("http://localhost")||0==a.indexOf("http://127.");h._tracker="http://"==h._httpProto&&!a&&"http://chemapps.stolaf.edu/jmol/JmolTracker.htm?id=UA-45940799-1";
+h._isChrome=0<=navigator.userAgent.toLowerCase().indexOf("chrome");h._isSafari=!h._isChrome&&0<=navigator.userAgent.toLowerCase().indexOf("safari");h._isMsie=void 0!==window.ActiveXObject;h._isEdge=0<=navigator.userAgent.indexOf("Edge/");h._useDataURI=!h._isSafari&&!h._isMsie&&!h._isEdge;window.requestAnimationFrame||(window.requestAnimationFrame=window.setTimeout);for(var e in Jmol)h[e]=Jmol[e];return h}(document,Jmol));
 (function(a,h){a.__$=h;h(document).ready(function(){a._document=null});a.$=function(b,a){null==b&&alert(a+arguments.callee.caller.toString());return h(a?"#"+b._id+"_"+a:b)};a._$=function(b){return"string"==typeof b?h("#"+b):b};a.$ajax=function(b){a._ajaxCall=b.url;b.cache="NO"!=b.cache;0==b.url.indexOf("http://pubchem.ncbi.nlm.nih")&&(b.url="https://"+b.url.substring(7));return h.ajax(b)};a._getNCIInfo=function(b,f){return a._getFileData("http://cactus.nci.nih.gov/chemical/structure/"+b+"/"+("name"==
 f?"names":f))};a.$appEvent=function(b,f,c,e){b=a.$(b,f);b.off(c)&&e&&b.on(c,e)};a.$resize=function(b){return h(window).resize(b)};a.$after=function(b,a){return h(b).after(a)};a.$append=function(b,a){return h(b).append(a)};a.$bind=function(b,a,c){return c?h(b).bind(a,c):h(b).unbind(a)};a.$closest=function(b,a){return h(b).closest(a)};a.$get=function(b,a){return h(b).get(a)};a.$documentOff=function(b,a){return h(document).off(b,"#"+a)};a.$documentOn=function(b,a,c){return h(document).on(b,"#"+a,c)};
 a.$getAncestorDiv=function(b,a){return h("div."+a+":has(#"+b+")")[0]};a.$supportsIECrossDomainScripting=function(){return h.support.iecors};a.$attr=function(b,f,c){return a._$(b).attr(f,c)};a.$css=function(b,f){return a._$(b).css(f)};a.$find=function(b,f){return a._$(b).find(f)};a.$focus=function(b){return a._$(b).focus()};a.$html=function(b,f){return a._$(b).html(f)};a.$offset=function(b){return a._$(b).offset()};a.$windowOn=function(b,a){return h(window).on(b,a)};a.$prop=function(b,f,c){var e=a._$(b);
@@ -44,13 +44,13 @@ a.Cache.put("cache://"+f,e);b.setData(f,c,e,d)};a._doAjax=function(b,f,c){b=b.to
 e||(e=d?"":"base64");(d=a._serverUrl)&&0<=d.indexOf("your.server")&&(d="");a._useDataURI||!d?(e||(f=btoa(f)),e=document.createElement("a"),e.href="data:"+c+";base64,"+f,e.type=c||"text/plain",e.download=b,e.target="_blank",h("body").append(e),e.click(),e.remove()):(a._formdiv||(a.$after("body",'<div id="__jsmolformdiv__" style="display:none">\t\t\t\t\t\t<form id="__jsmolform__" method="post" target="_blank" action="">\t\t\t\t\t\t<input name="call" value="saveFile"/>\t\t\t\t\t\t<input id="__jsmolmimetype__" name="mimetype" value=""/>\t\t\t\t\t\t<input id="__jsmolencoding__" name="encoding" value=""/>\t\t\t\t\t\t<input id="__jsmolfilename__" name="filename" value=""/>\t\t\t\t\t\t<textarea id="__jsmoldata__" name="data"></textarea>\t\t\t\t\t\t</form>\t\t\t\t\t\t</div>'),
 a._formdiv="__jsmolform__"),a.$attr(a._formdiv,"action",d+"?"+(new Date).getMilliseconds()),a.$val("__jsmoldata__",f),a.$val("__jsmolfilename__",b),a.$val("__jsmolmimetype__",c),a.$val("__jsmolencoding__",e),a.$submit("__jsmolform__"),a.$val("__jsmoldata__",""),a.$val("__jsmolfilename__",""));return"OK"};a._strToBytes=function(b){if(Clazz.instanceOf(b,self.ArrayBuffer))return Clazz.newByteArray(-1,b);for(var a=Clazz.newByteArray(b.length,0),c=b.length;0<=--c;)a[c]=b.charCodeAt(c)&255;return a};a._setConsoleDiv=
 function(b){self.Clazz&&Clazz.setConsoleDiv(b)};a._registerApplet=function(b,f){return window[b]=a._applets[b]=a._applets[b+"__"+a._syncId+"__"]=f};a._readyCallback=function(b,f,c,e,d){b=b.split("_object")[0];var g=a._applets[b];if(c=c.booleanValue?c.booleanValue():c)g._appletPanel=d||e,g._applet=e;a._track(g._readyCallback(b,f,c))};a._getWrapper=function(b,f){var c;if(f){var e="";if(b._coverImage)var e=' onclick="Jmol.coverApplet(ID, false)" title="'+b._coverTitle+'"',d='<image id="ID_coverclickgo" src="'+
-b._makeLiveImg+'" style="width:25px;height:25px;position:absolute;bottom:10px;left:10px;z-index:'+a._getZ(b,"coverImage")+';opacity:0.5;"'+e+" />",e='<div id="ID_coverdiv" style="background-color:red;z-index:'+a._getZ(b,"coverImage")+';width:100%;height:100%;display:inline;position:absolute;top:0px;left:0px"><image id="ID_coverimage" src="'+b._coverImage+'" style="width:100%;height:100%"'+e+"/>"+d+"</div>";d=b._isJava?"":'<image id="ID_waitimage" src="j2s/img/cursor_wait.gif" style="display:none;position:absolute;bottom:10px;left:10px;z-index:'+
+b._makeLiveImage+'" style="width:25px;height:25px;position:absolute;bottom:10px;left:10px;z-index:'+a._getZ(b,"coverImage")+';opacity:0.5;"'+e+" />",e='<div id="ID_coverdiv" style="background-color:red;z-index:'+a._getZ(b,"coverImage")+';width:100%;height:100%;display:inline;position:absolute;top:0px;left:0px"><image id="ID_coverimage" src="'+b._coverImage+'" style="width:100%;height:100%"'+e+"/>"+d+"</div>";d=b._isJava?"":'<image id="ID_waitimage" src="'+b._j2sPath+'/img/cursor_wait.gif" style="display:none;position:absolute;bottom:10px;left:10px;z-index:'+
 a._getZ(b,"coverImage")+';" />';c=a._appletCssText.replace(/\'/g,'"');var g=b._getSpinner&&b._getSpinner();b._spinner=g=!g||"none"==g?"":"background-image:url("+g+"); background-repeat:no-repeat; background-position:center;";c=g+(0<=c.indexOf('style="')?c.split('style="')[1]:'" '+c);c='...<div id="ID_appletinfotablediv" style="width:Wpx;height:Hpx;position:relative;font-size:14px;text-align:left">IMG WAIT......<div id="ID_appletdiv" style="z-index:'+a._getZ(b,"header")+";width:100%;height:100%;position:absolute;top:0px;left:0px;"+
 c+">";var g=b._height,h=b._width;if("string"!==typeof g||0>g.indexOf("%"))g+="px";if("string"!==typeof h||0>h.indexOf("%"))h+="px";c=c.replace(/IMG/,e).replace(/WAIT/,d).replace(/Hpx/g,g).replace(/Wpx/g,h)}else c='......</div>......<div id="ID_2dappletdiv" style="position:absolute;width:100%;height:100%;overflow:hidden;display:none"></div>......<div id="ID_infotablediv" style="width:100%;height:100%;position:absolute;top:0px;left:0px">.........<div id="ID_infoheaderdiv" style="height:20px;width:100%;background:yellow;display:none"><span id="ID_infoheaderspan"></span><span id="ID_infocheckboxspan" style="position:absolute;text-align:right;right:1px;"><a href="javascript:Jmol.showInfo(ID,false)">[x]</a></span></div>.........<div id="ID_infodiv" style="position:absolute;top:20px;bottom:0px;width:100%;height:100%;overflow:auto"></div>......</div>...</div>';
 return c.replace(/\.\.\./g,"").replace(/[\n\r]/g,"").replace(/ID/g,b._id)};a._hideLoadingSpinner=function(b){b._spinner&&a.$css(a.$(b,"appletdiv"),{"background-image":""})};a._documentWrite=function(b){if(a._document){if(a._isXHTML&&!a._XhtmlElement){var f=document.getElementsByTagName("script");a._XhtmlElement=f.item(f.length-1);a._XhtmlAppendChild=!1}a._XhtmlElement?a._domWrite(b):a._document.write(b)}return b};a._domWrite=function(b){for(var f=[0];f[0]<b.length;){var c=a._getDomElement(b,f);if(!c)break;
 a._XhtmlAppendChild?a._XhtmlElement.appendChild(c):a._XhtmlElement.parentNode.insertBefore(c,_jmol.XhtmlElement)}};a._getDomElement=function(b,a){var c=document.createElement("span");c.innerHTML=b;a[0]=b.length;return c};a._setObject=function(b,f,c){b._id=f;b.__Info={};c.z&&c.zIndexBase&&(a._z=a._getZOrders(c.zIndexBase));for(var e in c)b.__Info[e]=c[e];(b._z=c.z)||c.zIndexBase&&(b._z=b.__Info.z=a._getZOrders(c.zIndexBase));b._width=c.width;b._height=c.height;b._noscript=!b._isJava&&c.noscript;b._console=
 c.console;b._cacheFiles=!!c.cacheFiles;b._viewSet=null==c.viewSet||b._isJava?null:"Set"+c.viewSet;null!=b._viewSet&&(a.View.__init(b),b._currentView=null);!a._fileCache&&b._cacheFiles&&(a._fileCache={});b._console||(b._console=b._id+"_infodiv");"none"==b._console&&(b._console=null);b._color=c.color?c.color.replace(/0x/,"#"):"#FFFFFF";b._disableInitialConsole=c.disableInitialConsole;b._noMonitor=c.disableJ2SLoadMonitor;a._j2sPath&&(c.j2sPath=a._j2sPath);b._j2sPath=c.j2sPath;b._coverImage=c.coverImage;
-b._makeLiveImage=c.makeLiveImage||c._j2sPath+"/img/play_make_live.jpg";b._isCovered=!!b._coverImage;b._deferApplet=c.deferApplet||b._isCovered&&b._isJava;b._deferUncover=c.deferUncover&&!b._isJava;b._coverScript=c.coverScript;b._coverTitle=c.coverTitle;b._coverTitle||(b._coverTitle=b._deferApplet?"activate 3D model":"3D model is loading...");b._containerWidth=b._width+(b._width==parseFloat(b._width)?"px":"");b._containerHeight=b._height+(b._height==parseFloat(b._height)?"px":"");b._info="";b._infoHeader=
+b._makeLiveImage=c.makeLiveImage||c.j2sPath+"/img/play_make_live.jpg";b._isCovered=!!b._coverImage;b._deferApplet=c.deferApplet||b._isCovered&&b._isJava;b._deferUncover=c.deferUncover&&!b._isJava;b._coverScript=c.coverScript;b._coverTitle=c.coverTitle;b._coverTitle||(b._coverTitle=b._deferApplet?"activate 3D model":"3D model is loading...");b._containerWidth=b._width+(b._width==parseFloat(b._width)?"px":"");b._containerHeight=b._height+(b._height==parseFloat(b._height)?"px":"");b._info="";b._infoHeader=
 b._jmolType+' "'+b._id+'"';b._hasOptions=c.addSelectionOptions;b._defaultModel=c.defaultModel;b._readyScript=c.script?c.script:"";b._readyFunction=c.readyFunction;b._coverImage&&!b._deferApplet&&(b._readyScript+=";javascript "+f+"._displayCoverImage(false)");b._src=c.src};a._addDefaultInfo=function(b,f){for(var c in f)"undefined"==typeof b[c]&&(b[c]=f[c]);a._use&&(b.use=a._use);0<=b.use.indexOf("SIGNED")&&(0>b.jarFile.indexOf("Signed")&&(b.jarFile=b.jarFile.replace(/Applet/,"AppletSigned")),b.use=
 b.use.replace(/SIGNED/,"JAVA"),b.isSigned=!0)};a._syncedApplets=[];a._syncedCommands=[];a._syncedReady=[];a._syncReady=!1;a._isJmolJSVSync=!1;a._setReady=function(b){a._syncedReady[b]=1;for(var f=0,c=0;c<a._syncedApplets.length;c++){if(a._syncedApplets[c]==b._id)a._syncedApplets[c]=b,a._syncedReady[c]=1;else if(!a._syncedReady[c])continue;f++}f==a._syncedApplets.length&&a._setSyncReady()};a._setDestroy=function(b){a.featureDetection.allowDestroy&&a.$windowOn("beforeunload",function(){a._destroy(b)})};
 a._destroy=function(b){try{b._appletPanel&&b._appletPanel.destroy();b._applet=null;a._unsetMouse(b._canvas);b._canvas=null;for(var f=0,c=0;c<a._syncedApplets.length;c++)a._syncedApplets[c]==b&&(a._syncedApplets[c]=null),a._syncedApplets[c]&&f++;0<f||a._clearVars()}catch(e){}};a._setSyncReady=function(){a._syncReady=!0;for(var b="",f=0;f<a._syncedApplets.length;f++)a._syncedCommands[f]&&(b+="Jmol.script(Jmol._syncedApplets["+f+"], Jmol._syncedCommands["+f+"]);");setTimeout(b,50)};a._mySyncCallback=
