@@ -470,6 +470,7 @@ var checkSpecial = (nOperations == 1 && !this.doPackUnitCell ? false : this.asc.
 var checkSymmetryRange = (checkRangeNoSymmetry || checkRange111);
 var checkDistances = (checkSpecial || checkSymmetryRange);
 var addCartesian = (checkSpecial || checkSymmetryMinMax);
+var bsAtoms = (this.acr.isMolecular ? null : this.asc.bsAtoms);
 var symmetry = this.symmetry;
 if (checkRangeNoSymmetry) baseCount = this.noSymmetryCount;
 var atomMax = this.firstSymmetryAtom + this.noSymmetryCount;
@@ -483,7 +484,7 @@ var spinOp = (this.asc.vibScale == 0 ? symmetry.getSpinOp (iSym) : this.asc.vibS
 for (var i = this.firstSymmetryAtom; i < atomMax; i++) {
 var a = this.asc.atoms[i];
 if (a.ignoreSymmetry) continue;
-if (this.asc.bsAtoms != null && !this.asc.bsAtoms.get (i)) continue;
+if (bsAtoms != null && !bsAtoms.get (i)) continue;
 if (ms == null) {
 symmetry.newSpaceGroupPoint (iSym, a, ptAtom, transX, transY, transZ);
 } else {
@@ -600,6 +601,9 @@ for (var i = 0; i < operationCount; i++) symmetryList[i] = "" + this.symmetry.ge
 this.asc.setCurrentModelInfo ("symmetryOperations", symmetryList);
 this.asc.setCurrentModelInfo ("symmetryOps", this.symmetry.getSymmetryOperations ());
 }this.asc.setCurrentModelInfo ("symmetryCount", Integer.$valueOf (operationCount));
+this.asc.setCurrentModelInfo ("latticeType", this.symmetry.getLatticeType ());
+this.asc.setCurrentModelInfo ("intlTableNo", this.symmetry.getIntTableNumber ());
+if (this.acr.sgName == null || this.acr.sgName.indexOf ("?") >= 0 || this.acr.sgName.indexOf ("!") >= 0) this.setAtomSetSpaceGroupName (this.acr.sgName = this.symmetry.getSpaceGroupName ());
 });
 Clazz.defineMethod (c$, "getOverallSpan", 
 function () {
