@@ -525,6 +525,14 @@ function (slabObject) {
 if (this.slabInfo == null) this.slabInfo =  new JU.Lst ();
 this.slabInfo.addLast (slabObject);
 }, "~A");
+Clazz.defineMethod (c$, "isInsideOut", 
+function () {
+return this.insideOut != this.dataXYReversed;
+});
+Clazz.defineMethod (c$, "isFullyLit", 
+function () {
+return (this.thePlane != null || this.fullyLit);
+});
 Clazz.defineStatics (c$,
 "STATE_UNINITIALIZED", 0,
 "STATE_INITIALIZED", 1,
