@@ -58,7 +58,7 @@ function (i, rd, isVisible) {
 var atom = this.atoms[i];
 this.mads[i] = atom.calculateMad (this.vwr, rd);
 this.bsSizeSet.setBitTo (i, isVisible);
-this.setShapeVisibility (atom, isVisible);
+atom.setShapeVisibility (this.vf, isVisible);
 }, "~N,J.atomdata.RadiusData,~B");
 Clazz.defineMethod (c$, "setPropAS", 
 function (propertyName, value, bs) {
