@@ -1,5 +1,5 @@
 Clazz.declarePackage ("J.shape");
-Clazz.load (["J.shape.TextShape"], "J.shape.Echo", ["JU.PT", "JM.Object2d", "$.Text", "JU.C"], function () {
+Clazz.load (["J.shape.TextShape"], "J.shape.Echo", ["JU.PT", "JM.Text", "JU.C"], function () {
 c$ = Clazz.declareType (J.shape, "Echo", J.shape.TextShape);
 Clazz.overrideMethod (c$, "initShape", 
 function () {
@@ -13,27 +13,27 @@ var val = (value).floatValue ();
 this.currentObject.setScalePixelsPerMicron (val == 0 ? 0 : 10000 / val);
 }return;
 }if ("point" === propertyName) {
-if (this.currentObject == null) return;
+if (this.currentObject != null) {
 var t = this.currentObject;
 t.pointerPt = (value == null ? null : value);
 t.pointer = (value == null ? 0 : 1);
-return;
+}return;
 }if ("xyz" === propertyName) {
 if (this.currentObject != null && this.vwr.getBoolean (603979845)) this.currentObject.setScalePixelsPerMicron (this.vwr.getScalePixelsPerAngstrom (false) * 10000);
 }if ("scale" === propertyName) {
-if (this.currentObject == null) {
-if (this.isAll) for (var t, $t = this.objects.values ().iterator (); $t.hasNext () && ((t = $t.next ()) || true);) t.setScale ((value).floatValue ());
+if (this.currentObject != null) {
+(this.currentObject).setScale ((value).floatValue ());
+} else if (this.isAll) {
+for (var t, $t = this.objects.values ().iterator (); $t.hasNext () && ((t = $t.next ()) || true);) t.setScale ((value).floatValue ());
 
-return;
-}(this.currentObject).setScale ((value).floatValue ());
-return;
+}return;
 }if ("image" === propertyName) {
-if (this.currentObject == null) {
-if (this.isAll) for (var t, $t = this.objects.values ().iterator (); $t.hasNext () && ((t = $t.next ()) || true);) t.setImage (value);
+if (this.currentObject != null) {
+(this.currentObject).setImage (value);
+} else if (this.isAll) {
+for (var t, $t = this.objects.values ().iterator (); $t.hasNext () && ((t = $t.next ()) || true);) t.setImage (value);
 
-return;
-}(this.currentObject).setImage (value);
-return;
+}return;
 }if ("thisID" === propertyName) {
 var target = value;
 this.currentObject = this.objects.get (target);
@@ -41,18 +41,49 @@ if (this.currentObject == null && JU.PT.isWild (target)) this.thisID = target.to
 return;
 }if ("hidden" === propertyName) {
 var isHidden = (value).booleanValue ();
-if (this.currentObject == null) {
-if (this.isAll || this.thisID != null) for (var t, $t = this.objects.values ().iterator (); $t.hasNext () && ((t = $t.next ()) || true);) if (this.isAll || JU.PT.isMatch (t.target.toUpperCase (), this.thisID, true, true)) t.hidden = isHidden;
+if (this.currentObject != null) {
+(this.currentObject).hidden = isHidden;
+} else if (this.isAll || this.thisID != null) {
+for (var t, $t = this.objects.values ().iterator (); $t.hasNext () && ((t = $t.next ()) || true);) if (this.isAll || JU.PT.isMatch (t.target.toUpperCase (), this.thisID, true, true)) t.hidden = isHidden;
 
+}return;
+}if ("script" === propertyName) {
+if (this.currentObject != null) this.currentObject.setScript (value);
 return;
-}(this.currentObject).hidden = isHidden;
+}if ("xpos" === propertyName) {
+if (this.currentObject != null) this.currentObject.setMovableX ((value).intValue ());
 return;
-}if (JM.Object2d.setProperty (propertyName, value, this.currentObject)) return;
-if ("target" === propertyName) {
+}if ("ypos" === propertyName) {
+if (this.currentObject != null) this.currentObject.setMovableY ((value).intValue ());
+return;
+}if ("%xpos" === propertyName) {
+if (this.currentObject != null) this.currentObject.setMovableXPercent ((value).intValue ());
+return;
+}if ("%ypos" === propertyName) {
+if (this.currentObject != null) this.currentObject.setMovableYPercent ((value).intValue ());
+return;
+}if ("%zpos" === propertyName) {
+if (this.currentObject != null) this.currentObject.setMovableZPercent ((value).intValue ());
+return;
+}if ("xypos" === propertyName) {
+if (this.currentObject != null) {
+var pt = value;
+this.currentObject.setXYZ (null, true);
+if (pt.z == 3.4028235E38) {
+this.currentObject.setMovableX (Clazz.floatToInt (pt.x));
+this.currentObject.setMovableY (Clazz.floatToInt (pt.y));
+} else {
+this.currentObject.setMovableXPercent (Clazz.floatToInt (pt.x));
+this.currentObject.setMovableYPercent (Clazz.floatToInt (pt.y));
+}}return;
+}if ("xyz" === propertyName) {
+if (this.currentObject != null) {
+this.currentObject.setXYZ (value, true);
+}return;
+}if ("target" === propertyName) {
 this.thisID = null;
 var target = (value).intern ().toLowerCase ();
-if (target === "none" || target === "all") {
-} else {
+if (target !== "none" && target !== "all") {
 this.isAll = false;
 var text = this.objects.get (target);
 if (text == null) {
@@ -94,7 +125,7 @@ data[1] = id;
 return true;
 }}
 return false;
-}return false;
+}return this.getPropShape (property, data);
 }, "~S,~A");
 Clazz.overrideMethod (c$, "getShapeState", 
 function () {
