@@ -29,10 +29,8 @@ JU.BSUtil.deleteBits (this.bsHighlight, bs);
 Clazz.overrideMethod (c$, "setModelVisibilityFlags", 
 function (bs) {
 var bsSelected = (this.vwr.getSelectionHalosEnabled () ? this.vwr.bsA () : null);
-for (var i = this.ac; --i >= 0; ) {
-var isVisible = bsSelected != null && bsSelected.get (i) || (this.mads != null && this.mads[i] != 0);
-this.setShapeVisibility (this.atoms[i], isVisible);
-}
+for (var i = this.ac; --i >= 0; ) this.atoms[i].setShapeVisibility (this.vf, bsSelected != null && bsSelected.get (i) || this.mads != null && this.mads[i] != 0);
+
 }, "JU.BS");
 Clazz.overrideMethod (c$, "getShapeState", 
 function () {
