@@ -283,6 +283,10 @@ Clazz.overrideMethod (c$, "getImplicitHydrogenCount",
 function () {
 return this.group.chain.model.ms.getImplicitHydrogenCount (this, false);
 });
+Clazz.overrideMethod (c$, "getMissingHydrogenCount", 
+function () {
+return 0;
+});
 Clazz.defineMethod (c$, "getTargetValence", 
 function () {
 switch (this.getElementNumber ()) {
@@ -1015,6 +1019,21 @@ function (flags) {
 var m = this.group.getModel ();
 return (m.isBioModel ? (m).getUnitID (this, flags) : "");
 }, "~N");
+Clazz.overrideMethod (c$, "getFloatProperty", 
+function (property) {
+var data = this.group.chain.model.ms.vwr.getDataObj (property, null, 1);
+var f = 0;
+if (data != null) {
+try {
+f = (data)[this.i];
+} catch (e) {
+if (Clazz.exceptionOf (e, Exception)) {
+} else {
+throw e;
+}
+}
+}return f;
+}, "~S");
 Clazz.defineStatics (c$,
 "ATOM_INFRAME", 1,
 "ATOM_VISSET", 2,
