@@ -200,11 +200,21 @@ var iArray = -1;
 for (var i = eval.iToken; i < this.slen; ++i) {
 var propertyName = null;
 var propertyValue = null;
-switch (this.getToken (i).tok) {
+var tok = this.getToken (i).tok;
+switch (tok) {
 case 1747587102:
 case 1678381065:
 if (this.chk) break;
-var vp = this.vwr.getPlaneIntersection (eval.theTok, null, intScale / 100, 0);
+var uc = null;
+if (tok == 1747587102) {
+if (eval.isArrayParameter (i + 1)) {
+var points = eval.getPointArray (i + 1, -1, false);
+uc = this.vwr.ms.getSymTemp (true).getUnitCell (points, false, null);
+i = eval.iToken;
+} else {
+uc = this.vwr.getCurrentUnitCell ();
+}if (uc == null) this.invArg ();
+}var vp = this.getPlaneIntersection (tok, null, uc, intScale / 100, 0);
 intScale = 0;
 propertyName = "polygon";
 propertyValue = vp;
@@ -278,8 +288,8 @@ nVertices = Math.max (0, this.intParameter (i));
 points =  new Array (nVertices);
 for (var j = 0; j < nVertices; j++) points[j] = this.centerParameter (++eval.iToken);
 
-i = eval.iToken;
-}var polygons = null;
+}i = eval.iToken;
+var polygons = null;
 switch (this.tokAt (i + 1)) {
 case 11:
 case 12:
@@ -374,7 +384,7 @@ plane = eval.hklParameter (++i);
 }i = eval.iToken;
 if (tokIntersect != 0) {
 if (this.chk) break;
-var vpc = this.vwr.getPlaneIntersection (tokIntersect, plane, intScale / 100, 0);
+var vpc = this.getPlaneIntersection (tokIntersect, plane, null, intScale / 100, 0);
 intScale = 0;
 propertyName = "polygon";
 propertyValue = vpc;
@@ -576,6 +586,10 @@ if (propertyName != null) this.setShapeProperty (22, propertyName, propertyValue
 this.finalizeObject (22, colorArgb[0], translucentLevel, intScale, havePoints, connections, iptDisplayProperty, null);
 return true;
 });
+Clazz.defineMethod (c$, "getPlaneIntersection", 
+ function (type, plane, uc, scale, flags) {
+return this.vwr.ms.getPlaneIntersection (type, plane, scale, flags, uc);
+}, "~N,JU.P4,J.api.SymmetryInterface,~N,~N");
 Clazz.defineMethod (c$, "mo", 
  function (isInitOnly, iShape) {
 var eval = this.e;
