@@ -22,6 +22,13 @@ sv.tok = 2;
 sv.intValue = i;
 return sv;
 }, "~N");
+c$.newF = Clazz.defineMethod (c$, "newF", 
+function (f) {
+var sv =  new JS.SV ();
+sv.tok = 3;
+sv.value = Float.$valueOf (f);
+return sv;
+}, "~N");
 c$.newS = Clazz.defineMethod (c$, "newS", 
 function (s) {
 return JS.SV.newV (4, s);
@@ -120,7 +127,29 @@ if (JU.AU.isAFF (x)) return JS.SV.getVariableAFF (x);
 if (JU.AU.isASS (x)) return JS.SV.getVariableASS (x);
 if (JU.AU.isADD (x)) return JS.SV.getVariableADD (x);
 if (JU.AU.isAFloat (x)) return JS.SV.newV (13, x);
-return JS.SV.newS (x.toString ());
+return JS.SV.newJSVar (x);
+}, "~O");
+c$.newJSVar = Clazz.defineMethod (c$, "newJSVar", 
+ function (x) {
+{
+switch(x.BYTES_PER_ELEMENT ? Array : x.constructor) {
+case Boolean:
+return (x ? JS.SV.vT : JS.SV.vF);
+case Number:
+return (x > Integer.MAX_VALUE || x != Math.floor(x) ? JS.SV.newF(x) : JS.SV.newI(x));
+case Array:
+var v =  new JU.Lst();
+for (var i = 0, n = x.length; i < n; i++)
+v.addLast(JS.SV.newJSVar(x[i]));
+return JS.SV.getVariableList(v);
+case Object:
+var keys = Object.keys(x);
+var v =  new java.util.Hashtable();
+for (var i = keys.length; --i >= 0;)
+v.put(keys[i],JS.SV.newJSVar(x[keys[i]]));
+return JS.SV.getVariableMap(v);
+}
+}return JS.SV.newS (x.toString ());
 }, "~O");
 c$.getVariableMap = Clazz.defineMethod (c$, "getVariableMap", 
 function (x) {
@@ -745,13 +774,13 @@ while (pt2 >= str.length) str += " ";
 this.intValue = this.index = 2147483647;
 break;
 case 7:
-len = this.getList ().size ();
+var v = this.value;
+len = v.size ();
 if (pt1 <= 0) pt1 = len + pt1;
 if (--pt1 < 0) pt1 = 0;
-if (len <= pt1) {
-for (var i = len; i <= pt1; i++) this.getList ().addLast (JS.SV.newV (4, ""));
+if (len <= pt1) for (var i = len; i <= pt1; i++) v.addLast (JS.SV.newV (4, ""));
 
-}this.getList ().set (pt1, $var);
+v.set (pt1, $var);
 break;
 }
 }, "~N,~N,JS.SV");
@@ -972,8 +1001,17 @@ function (value, mapKey) {
 if (mapKey != null) {
 var m = this.getMap ();
 if (value == null) {
-var v;
-return (m == null || (v = m.remove (mapKey.asString ())) == null ? JS.SV.newS ("") : v);
+var v = null;
+if (m == null) {
+var lst = this.getList ();
+var len = lst.size ();
+var i = JS.SV.iValue (mapKey) - 1;
+if (i < 0) i += len;
+if (i >= 0 && i < len) {
+v = lst.remove (i);
+}} else {
+v = m.remove (mapKey.asString ());
+}return (v == null ? JS.SV.newS ("") : v);
 }if (m != null) m.put (mapKey.asString (), JS.SV.newI (0).setv (value));
 } else {
 var x = this.getList ();
