@@ -98,6 +98,7 @@ throw e;
 }
 }
 }if (++this.xPt == this.xStack.length) this.xStack = JU.AU.doubleLength (this.xStack);
+if (this.xPt < 0) System.out.println ("testing scriptemaafe");
 this.xStack[this.xPt] = x;
 this.ptx = ++this.ptid;
 if (this.debugHigh) {
@@ -550,6 +551,7 @@ for (var i = nParam; --i >= 0; ) args[i] = this.getX ();
 this.xPt--;
 if (!this.chk) return this.eval.getMathExt ().evaluate (this, op, args, tok);
 if (op.tok == 268435665) this.xPt--;
+if (this.xPt < 0) this.xPt = 0;
 switch (tok) {
 case 134217736:
 case 1275203608:
@@ -1081,7 +1083,7 @@ return false;
 case 10:
 return this.addXBs (JS.SV.bsSelectRange (x1, n));
 }
-return this.addXInt (n == 0 ? 0 : x1.asInt () % n);
+return this.addXInt (n == 0 ? x1.asInt () : x1.asInt () % n);
 }
 return true;
 }, "JS.T,JS.SV,JS.SV");
