@@ -1,10 +1,11 @@
 Clazz.declarePackage ("JS");
-Clazz.load (["java.util.Hashtable", "JU.BS", "JS.VTemp"], "JS.SmilesGenerator", ["JU.Lst", "$.SB", "JS.InvalidSmilesException", "$.SmilesAtom", "$.SmilesBond", "$.SmilesParser", "$.SmilesSearch", "$.SmilesStereo", "JU.BNode", "$.BSUtil", "$.Elements", "$.JmolMolecule", "$.Logger"], function () {
+Clazz.load (["java.util.Hashtable", "JU.BS", "JS.VTemp"], "JS.SmilesGenerator", ["JU.AU", "$.Lst", "$.SB", "JS.InvalidSmilesException", "$.SmilesAtom", "$.SmilesBond", "$.SmilesParser", "$.SmilesSearch", "$.SmilesStereo", "JU.BNode", "$.BSUtil", "$.Elements", "$.JmolMolecule", "$.Logger"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.atoms = null;
 this.ac = 0;
 this.bsSelected = null;
 this.bsAromatic = null;
+this.flags = 0;
 this.explicitH = false;
 this.ringSets = null;
 this.vTemp = null;
@@ -24,9 +25,12 @@ this.getAromatic = true;
 this.addAtomComment = false;
 this.noBioComment = false;
 this.noStereo = false;
+this.openSMILES = false;
 this.stereoReference = null;
 this.smilesStereo = null;
 this.isPolyhedral = false;
+this.aromaticRings = null;
+this.atemp = null;
 Clazz.instantialize (this, arguments);
 }, JS, "SmilesGenerator");
 Clazz.prepareFields (c$, function () {
@@ -41,26 +45,29 @@ Clazz.defineMethod (c$, "getSmiles",
 function (atoms, ac, bsSelected, comment, flags) {
 var ipt = bsSelected.nextSetBit (0);
 if (ipt < 0) return "";
+this.flags = flags;
 this.atoms = atoms;
 this.ac = ac;
-this.addAtomComment = ((flags & 524288) == 524288);
 bsSelected = JU.BSUtil.copy (bsSelected);
-if ((flags & 65536) == 65536) return this.getBioSmiles (bsSelected, comment, flags);
+if ((flags & 1048576) == 1048576) return this.getBioSmiles (bsSelected, comment, flags);
 this.bsSelected = bsSelected;
-this.explicitH = ((flags & 256) == 256);
-this.topologyOnly = ((flags & 512) == 512);
-this.getAromatic = !((flags & 1024) == 1024);
-this.noStereo = ((flags & 2048) == 2048);
-this.isPolyhedral = ((flags & 4096) == 4096);
+this.flags = flags = JS.SmilesSearch.addFlags (flags, comment == null ? "" : comment.toUpperCase ());
+this.openSMILES = ((flags & 5) == 5);
+this.addAtomComment = ((flags & 131072) == 131072);
+this.explicitH = ((flags & 4096) == 4096);
+this.topologyOnly = ((flags & 8192) == 8192);
+this.getAromatic = !((flags & 16384) == 16384);
+this.noStereo = ((flags & 32768) == 32768);
+this.isPolyhedral = ((flags & 65536) == 65536);
 return this.getSmilesComponent (atoms[ipt], bsSelected, true, false, false);
 }, "~A,~N,JU.BS,~S,~N");
 Clazz.defineMethod (c$, "getBioSmiles", 
  function (bsSelected, comment, flags) {
-this.addAtomComment = ((flags & 524288) == 524288);
-var allowUnmatchedRings = ((flags & 69632) == 69632);
-var noBioComments = ((flags & 327680) == 327680);
-var crosslinkCovalent = ((flags & 73728) == 73728);
-var crosslinkHBonds = ((flags & 90112) == 90112);
+this.addAtomComment = ((flags & 131072) == 131072);
+var allowUnmatchedRings = ((flags & 3145728) == 3145728);
+var noBioComments = ((flags & 34603008) == 34603008);
+var crosslinkCovalent = ((flags & 5242880) == 5242880);
+var crosslinkHBonds = ((flags & 9437184) == 9437184);
 var addCrosslinks = (crosslinkCovalent || crosslinkHBonds);
 var sb =  new JU.SB ();
 var bs = bsSelected;
@@ -180,16 +187,18 @@ var a = this.atoms[j];
 if (a.getElementNumber () == 1 && a.getIsotopeNumber () == 0) this.bsSelected.clear (j);
 }
 if (this.getAromatic && !this.topologyOnly && this.bsSelected.cardinality () > 2) {
-var search = null;
-search = JS.SmilesParser.getMolecule ("A[=&@]A", true);
+var search = JS.SmilesParser.getMolecule ("A[=&@]A", true);
 search.jmolAtoms = this.atoms;
 if (Clazz.instanceOf (this.atoms, Array)) search.bioAtoms = this.atoms;
 search.setSelected (this.bsSelected);
 search.jmolAtomCount = this.ac;
 search.ringDataMax = 7;
-search.setRingData (null);
+search.flags = this.flags;
+var vRings = JU.AU.createArrayOfArrayList (4);
+search.setRingData (null, vRings, true);
 this.bsAromatic = search.bsAromatic;
 this.ringSets = search.ringSets;
+this.aromaticRings = vRings[3];
 this.setBondDirections ();
 } else {
 this.bsAromatic =  new JU.BS ();
@@ -237,10 +246,20 @@ var bonds = atom1.getEdges ();
 for (var k = 0; k < bonds.length; k++) {
 var bond = bonds[k];
 var index = bond.index;
-if (bsDone.get (index)) continue;
-var atom2 = bond.getOtherAtomNode (atom1);
-if (bond.getCovalentOrder () != 2 || JS.SmilesSearch.isRingBond (this.ringSets, i, atom2.getIndex ())) continue;
+var atom2;
+if (bsDone.get (index) || bond.getCovalentOrder () != 2 || JS.SmilesSearch.isRingBond (this.ringSets, i, (atom2 = bond.getOtherAtomNode (atom1)).getIndex ())) continue;
 bsDone.set (index);
+var nCumulene = 0;
+var a10 = atom1;
+while (atom2.getBondCount () == 2 && atom2.getValence () == 4) {
+var e2 = atom2.getEdges ();
+var e = e2[e2[0].getOtherAtomNode (atom2) === a10 ? 1 : 0];
+bsDone.set (e.index);
+a10 = atom2;
+atom2 = e.getOtherAtomNode (atom2);
+nCumulene++;
+}
+if (nCumulene % 2 == 1) continue;
 var b0 = null;
 var a0 = null;
 var i0 = 0;
@@ -252,7 +271,7 @@ edgeCount = 0;
 var atomA = atom12[j];
 var bb = atomA.getEdges ();
 for (var b = 0; b < bb.length; b++) {
-if (bb[b].getCovalentOrder () != 1) continue;
+if (bb[b].getCovalentOrder () != 1 || bb[b].getOtherAtomNode (atomA).getElementNumber () == 1) continue;
 edges[j][edgeCount++] = bb[b];
 if (this.getBondStereochemistry (bb[b], atomA) != '\0') {
 b0 = bb[b];
@@ -333,7 +352,7 @@ v.addLast (bonds[i]);
 var strBond = null;
 if (sp2Atoms == null) sp2Atoms =  new Array (5);
 if (bondPrev != null) {
-strBond = (isAromatic && this.bsAromatic.get (prevIndex) ? "" : JS.SmilesBond.getBondOrderString (bondPrev.getCovalentOrder ()));
+strBond = this.getBondOrder (bondPrev, atomIndex, prevIndex, isAromatic);
 if (this.prevSp2Atoms == null) sp2Atoms[nSp2Atoms++] = this.prevAtom;
  else nSp2Atoms = 2;
 }nSp2Atoms += nH;
@@ -352,7 +371,9 @@ bond0 = bond;
 }}
 var atomNext = (bond0 == null ? null : bond0.getOtherAtomNode (atom));
 var orderNext = (bond0 == null ? 0 : bond0.getCovalentOrder ());
-if (stereoFlag < 7 && bondPrev != null) {
+if (isAromatic || orderNext == 2 && nH > 1 || atomNext != null && JS.SmilesSearch.isRingBond (this.ringSets, atomIndex, atomNext.getIndex ())) {
+sp2Atoms = null;
+}if (stereoFlag < 7 && bondPrev != null) {
 if (bondPrev.getCovalentOrder () == 2 && orderNext == 2 && this.prevSp2Atoms != null && this.prevSp2Atoms[1] != null) {
 stereo[stereoFlag++] = this.prevSp2Atoms[0];
 stereo[stereoFlag++] = this.prevSp2Atoms[1];
@@ -361,7 +382,12 @@ stereo[stereoFlag++] = this.prevAtom;
 }}if (stereoFlag < 7 && nH == 1) stereo[stereoFlag++] = aH;
 var deferStereo = (orderNext == 1 && this.prevSp2Atoms == null);
 var chBond = this.getBondStereochemistry (bondPrev, this.prevAtom);
-var sMore =  new JU.SB ();
+if (strBond != null || chBond != '\0') {
+if (chBond != '\0') strBond = "" + chBond;
+sb.append (strBond);
+}var sbBranches =  new JU.SB ();
+var stereoFlag0 = stereoFlag;
+var nSp2Atoms0 = nSp2Atoms;
 for (var i = 0; i < v.size (); i++) {
 var bond = v.get (i);
 if (!bsBranches.get (bond.index)) continue;
@@ -374,34 +400,32 @@ var bond0t = bond0;
 this.getSmilesAt (s2, a, allowConnectionsToOutsideWorld, allowBranches, explicitH, forceBrackets);
 bond0 = bond0t;
 s2.append (")");
-if (sMore.indexOf (s2.toString ()) >= 0) stereoFlag = 10;
-sMore.appendSB (s2);
+if (sbBranches.indexOf (s2.toString ()) >= 0) stereoFlag = 10;
+sbBranches.appendSB (s2);
 v.remove (i--);
 if (stereoFlag < 7) stereo[stereoFlag++] = a;
-if (nSp2Atoms < 5) sp2Atoms[nSp2Atoms++] = a;
+if (sp2Atoms != null && nSp2Atoms < 5) sp2Atoms[nSp2Atoms++] = a;
 }
-var index2 = (orderNext == 2 ? atomNext.getIndex () : -1);
-if (nH > 1 || isAromatic || index2 < 0 || JS.SmilesSearch.isRingBond (this.ringSets, atomIndex, index2)) {
-nSp2Atoms = -1;
-}if (nSp2Atoms < 0) sp2Atoms = null;
-if (strBond != null || chBond != '\0') {
-if (chBond != '\0') strBond = "" + chBond;
-sb.append (strBond);
-}var atat = null;
+var sbRings =  new JU.SB ();
+var stereoFlag1 = stereoFlag;
+var nSp2Atoms1 = nSp2Atoms;
+var atat = null;
 if (!allowBranches && !this.noStereo && this.stereoReference == null && (v.size () == 5 || v.size () == 6)) atat = this.sortInorganic (atom, v, this.vTemp);
 for (var i = 0; i < v.size (); i++) {
 var bond = v.get (i);
 if (bond === bond0) continue;
 var a = bond.getOtherAtomNode (atom);
-strBond = JS.SmilesBond.getBondOrderString (bond.order);
+strBond = this.getBondOrder (bond, atomIndex, a.getIndex (), isAromatic);
 if (!deferStereo) {
 chBond = this.getBondStereochemistry (bond, atom);
 if (chBond != '\0') strBond = "" + chBond;
-}sMore.append (strBond);
-sMore.append (this.getRingCache (atomIndex, a.getIndex (), this.htRings));
+}sbRings.append (strBond);
+sbRings.append (this.getRingCache (atomIndex, a.getIndex (), this.htRings));
 if (stereoFlag < 7) stereo[stereoFlag++] = a;
 if (sp2Atoms != null && nSp2Atoms < 5) sp2Atoms[nSp2Atoms++] = a;
 }
+if (stereoFlag0 != stereoFlag1 && stereoFlag1 != stereoFlag) this.swapArray (stereo, stereoFlag0, stereoFlag1, stereoFlag);
+if (sp2Atoms != null && nSp2Atoms0 != nSp2Atoms1 && nSp2Atoms1 != nSp2Atoms) this.swapArray (sp2Atoms, nSp2Atoms0, nSp2Atoms1, nSp2Atoms);
 if (havePreviousSp2Atoms && stereoFlag == 2 && orderNext == 2 && atomNext.getCovalentBondCount () == 3) {
 bonds = atomNext.getEdges ();
 for (var k = 0; k < bonds.length; k++) {
@@ -413,15 +437,17 @@ stereo[stereoFlag++] = atomNext;
 }var charge = atom.getFormalCharge ();
 var isotope = atom.getIsotopeNumber ();
 var valence = atom.getValence ();
+var osclass = (this.openSMILES ? atom.getFloatProperty ("property_atomclass") : 0);
 var atomName = atom.getAtomName ();
 var groupType = (Clazz.instanceOf (atom, JU.BNode) ? (atom).getBioStructureTypeName () : "");
 if (this.addAtomComment) sb.append ("\n//* " + atom.toString () + " *//\t");
 if (this.topologyOnly) sb.append ("*");
  else if (isExtension && groupType.length != 0 && atomName.length != 0) this.addBracketedBioName (sb, atom, "." + atomName, false);
- else sb.append (JS.SmilesAtom.getAtomLabel (atomicNumber, isotope, (forceBrackets ? -1 : valence), charge, nH, isAromatic, atat != null ? atat : this.noStereo ? null : this.checkStereoPairs (atom, atomIndex, stereo, stereoFlag)));
-sb.appendSB (sMore);
+ else sb.append (JS.SmilesAtom.getAtomLabel (atomicNumber, isotope, (forceBrackets ? -1 : valence), charge, osclass, nH, isAromatic, atat != null ? atat : this.noStereo ? null : this.checkStereoPairs (atom, atomIndex, stereo, stereoFlag)));
+sb.appendSB (sbRings).appendSB (sbBranches);
+System.out.println (sb);
 if (bond0 == null) return null;
-if (orderNext == 2 && (nSp2Atoms == 1 || nSp2Atoms == 2)) {
+if (sp2Atoms != null && orderNext == 2 && (nSp2Atoms == 1 || nSp2Atoms == 2)) {
 if (sp2Atoms[0] == null) sp2Atoms[0] = atom;
 if (sp2Atoms[1] == null) sp2Atoms[1] = atom;
 } else {
@@ -431,6 +457,29 @@ nSp2Atoms = 0;
 this.prevAtom = atom;
 return atomNext;
 }, "JU.SB,JU.Node,~B,~B,~B,~B");
+Clazz.defineMethod (c$, "swapArray", 
+ function (a, i0, i1, i2) {
+var n = i1 - i0;
+if (this.atemp == null || this.atemp.length < n) this.atemp =  new Array (n);
+for (var p = n, i = i1; p > 0; ) this.atemp[--p] = a[--i];
+
+for (var i = i1; i < i2; i++) a[i - n] = a[i];
+
+for (var p = n, i = i2; p > 0; ) a[--i] = this.atemp[--p];
+
+}, "~A,~N,~N,~N");
+Clazz.defineMethod (c$, "getBondOrder", 
+ function (bondPrev, atomIndex, prevIndex, isAromatic) {
+var border = bondPrev.getCovalentOrder ();
+return (!isAromatic || !this.bsAromatic.get (prevIndex) ? JS.SmilesBond.getBondOrderString (border) : border == 1 && !this.isSameAromaticRing (atomIndex, prevIndex) ? "-" : "");
+}, "JU.Edge,~N,~N,~B");
+Clazz.defineMethod (c$, "isSameAromaticRing", 
+ function (a1, a2) {
+var bs;
+for (var i = this.aromaticRings.size (); --i >= 0; ) if ((bs = this.aromaticRings.get (i)).get (a1) && bs.get (a2)) return true;
+
+return false;
+}, "~N,~N");
 Clazz.defineMethod (c$, "sortBonds", 
 function (atom, refAtom, center) {
 if (this.smilesStereo == null) try {
@@ -451,6 +500,8 @@ var axialPairs =  new JU.Lst ();
 var bonds =  new JU.Lst ();
 var a1;
 var a2;
+var a01 = null;
+var a02 = null;
 var bond1;
 var bond2;
 var bsDone =  new JU.BS ();
@@ -458,6 +509,7 @@ var pair0 = null;
 var stereo =  new Array (6);
 var isOK = true;
 var s = "";
+var naxial = 0;
 for (var i = 0; i < n; i++) {
 bond1 = v.get (i);
 stereo[0] = a1 = bond1.getOtherAtomNode (atom);
@@ -471,6 +523,20 @@ if (bsDone.get (j)) continue;
 bond2 = v.get (j);
 a2 = bond2.getOtherAtomNode (atom);
 if (JS.SmilesStereo.isDiaxial (atom, atom, a1, a2, vTemp, -0.95)) {
+switch (++naxial) {
+case 1:
+a01 = a1;
+break;
+case 2:
+a02 = a1;
+break;
+case 3:
+if (JS.SmilesStereo.getHandedness (a02, a01, a1, atom, vTemp) == 2) {
+var b = bond1;
+bond1 = bond2;
+bond2 = b;
+}break;
+}
 axialPairs.addLast ( Clazz.newArray (-1, [bond1, bond2]));
 isAxial = true;
 bsDone.set (j);
@@ -495,6 +561,7 @@ v.addLast (bond1);
 stereo[i + 1] = bond1.getOtherAtomNode (atom);
 }
 v.addLast (pair0[1]);
+stereo[n - 1] = pair0[1].getOtherAtomNode (atom);
 return JS.SmilesStereo.getStereoFlag (atom, stereo, n, vTemp);
 }, "JU.Node,JU.Lst,JS.VTemp");
 Clazz.defineMethod (c$, "checkStereoPairs", 
