@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JS");
-Clazz.load (["J.api.SmilesMatcherInterface"], "JS.SmilesMatcher", ["JU.AU", "$.BS", "$.PT", "JS.InvalidSmilesException", "$.SmilesAtom", "$.SmilesBond", "$.SmilesGenerator", "$.SmilesParser", "JU.BSUtil", "$.Elements", "$.Logger", "$.Node", "$.Point3fi"], function () {
+Clazz.load (["J.api.SmilesMatcherInterface"], "JS.SmilesMatcher", ["JU.AU", "$.BS", "$.PT", "JS.InvalidSmilesException", "$.SmilesAtom", "$.SmilesBond", "$.SmilesGenerator", "$.SmilesParser", "$.SmilesSearch", "JU.BNode", "$.BSUtil", "$.Elements", "$.Logger", "$.Node", "$.Point3fi"], function () {
 c$ = Clazz.declareType (JS, "SmilesMatcher", null, J.api.SmilesMatcherInterface);
 Clazz.overrideMethod (c$, "getLastException", 
 function () {
@@ -8,7 +8,7 @@ return JS.InvalidSmilesException.getLastError ();
 Clazz.overrideMethod (c$, "getMolecularFormula", 
 function (pattern, isSmarts) {
 JS.InvalidSmilesException.clear ();
-var search = JS.SmilesParser.getMolecule (pattern, isSmarts);
+var search = JS.SmilesParser.getMolecule ("/nostereo/" + pattern, isSmarts);
 search.createTopoMap (null);
 search.nodes = search.jmolAtoms;
 return search.getMolecularFormula (!isSmarts, null, false);
@@ -21,12 +21,12 @@ return ( new JS.SmilesGenerator ()).getSmiles (atoms, ac, bsSelected, bioComment
 Clazz.overrideMethod (c$, "areEqual", 
 function (smiles1, smiles2) {
 JS.InvalidSmilesException.clear ();
-var result = this.findPriv (smiles1, JS.SmilesParser.getMolecule (smiles2, false), (smiles1.indexOf ("*") >= 0 ? 2 : 17) | 64 | 8192);
+var result = this.findPriv (smiles1, JS.SmilesParser.getMolecule (smiles2, false), (smiles1.indexOf ("*") >= 0 ? 2 : 1) | 32, 2);
 return (result == null ? -1 : result.length);
 }, "~S,~S");
 Clazz.defineMethod (c$, "areEqualTest", 
 function (smiles, molecule) {
-var ret = this.findPriv (smiles, molecule, 8273);
+var ret = this.findPriv (smiles, molecule, 33, 2);
 return (ret != null && ret.length == 1);
 }, "~S,JS.SmilesSearch");
 Clazz.overrideMethod (c$, "find", 
@@ -35,7 +35,7 @@ JS.InvalidSmilesException.clear ();
 smiles = JS.SmilesParser.cleanPattern (smiles);
 pattern = JS.SmilesParser.cleanPattern (pattern);
 var search = JS.SmilesParser.getMolecule (smiles, false);
-var array = this.findPriv (pattern, search, (isSmarts ? 2 : 17) | (firstMatchOnly ? 64 : 0) | 12288);
+var array = this.findPriv (pattern, search, (isSmarts ? 2 : 1) | (firstMatchOnly ? 32 : 0), 3);
 for (var i = array.length; --i >= 0; ) {
 var a = array[i];
 for (var j = a.length; --j >= 0; ) a[j] = (search.jmolAtoms[a[j]]).mapIndex;
@@ -56,7 +56,7 @@ check = (n1 == n2 && this.areEqual (smiles2, smiles1) > 0);
 if (!check) {
 var s = smiles1 + smiles2;
 if (s.indexOf ("/") >= 0 || s.indexOf ("\\") >= 0 || s.indexOf ("@") >= 0) {
-if (n1 == n2 && n1 > 0) {
+if (n1 == n2 && n1 > 0 && s.indexOf ("@SP") < 0) {
 check = (this.areEqual ("/invertstereo/" + smiles2, smiles1) > 0);
 if (check) return "enantiomers";
 }check = (this.areEqual ("/nostereo/" + smiles2, smiles1) > 0);
@@ -73,20 +73,21 @@ return smiles;
 }, "~S");
 Clazz.overrideMethod (c$, "getSubstructureSet", 
 function (pattern, atoms, ac, bsSelected, flags) {
-return this.matchPriv (pattern, atoms, ac, bsSelected, null, flags | 32 | 4096);
+return this.matchPriv (pattern, atoms, ac, bsSelected, null, true, flags, 1);
 }, "~S,~A,~N,JU.BS,~N");
-Clazz.overrideMethod (c$, "getSubstructureSets", 
-function (smarts, atoms, ac, flags, bsSelected, ret, vRings) {
+Clazz.overrideMethod (c$, "getMMFF94AtomTypes", 
+function (smarts, atoms, ac, bsSelected, ret, vRings) {
 JS.InvalidSmilesException.clear ();
 var sp =  new JS.SmilesParser (true);
 var search = null;
+var flags = (1794);
 search = sp.parse ("");
-search.firstMatchOnly = false;
-search.matchAllAtoms = false;
+search.exitFirstMatch = false;
 search.jmolAtoms = atoms;
 search.jmolAtomCount = Math.abs (ac);
 search.setSelected (bsSelected);
-search.getRingData (true, flags, vRings);
+search.flags = flags;
+search.getRingData (vRings, true, true);
 search.asVector = false;
 search.subSearches =  new Array (1);
 search.getSelections ();
@@ -98,15 +99,15 @@ continue;
 }search.clear ();
 var ss = sp.getSearch (search, JS.SmilesParser.cleanPattern (smarts[i]), flags);
 search.subSearches[0] = ss;
-var bs = JU.BSUtil.copy (search.search (false));
+var bs = JU.BSUtil.copy (search.search ());
 ret.addLast (bs);
 bsDone.or (bs);
 if (bsDone.cardinality () == ac) return;
 }
-}, "~A,~A,~N,~N,JU.BS,JU.Lst,~A");
+}, "~A,~A,~N,JU.BS,JU.Lst,~A");
 Clazz.overrideMethod (c$, "getSubstructureSetArray", 
 function (pattern, atoms, ac, bsSelected, bsAromatic, flags) {
-return this.matchPriv (pattern, atoms, ac, bsSelected, bsAromatic, flags | 32 | 8192);
+return this.matchPriv (pattern, atoms, ac, bsSelected, bsAromatic, true, flags, 2);
 }, "~S,~A,~N,JU.BS,JU.BS,~N");
 Clazz.overrideMethod (c$, "polyhedronToSmiles", 
 function (center, faces, atomCount, points, flags, details) {
@@ -144,47 +145,51 @@ var s = null;
 var g =  new JS.SmilesGenerator ();
 if (points != null) g.stereoReference = center;
 JS.InvalidSmilesException.clear ();
-s = g.getSmiles (atoms, atomCount, JU.BSUtil.newBitSet2 (0, atomCount), null, flags | 256 | 1024 | 2048);
-if ((flags & 4096) == 4096) {
+s = g.getSmiles (atoms, atomCount, JU.BSUtil.newBitSet2 (0, atomCount), null, flags | 4096 | 16384 | 32768);
+if ((flags & 65536) == 65536) {
 s = "//* " + center + " *//\t[" + JU.Elements.elementSymbolFromNumber (center.getElementNumber ()) + "@PH" + atomCount + (details == null ? "" : "/" + details + "/") + "]." + s;
 }return s;
 }, "JU.Node,~A,~N,~A,~N,~S");
 Clazz.overrideMethod (c$, "getCorrelationMaps", 
 function (pattern, atoms, atomCount, bsSelected, flags) {
-return this.matchPriv (pattern, atoms, atomCount, bsSelected, null, flags | 32 | 12288);
+return this.matchPriv (pattern, atoms, atomCount, bsSelected, null, true, flags, 3);
 }, "~S,~A,~N,JU.BS,~N");
 Clazz.defineMethod (c$, "findPriv", 
- function (pattern, search, flags) {
+ function (pattern, search, flags, mode) {
 var bsAromatic =  new JU.BS ();
+search.setFlags (search.flags | JS.SmilesParser.getFlags (pattern));
 search.createTopoMap (bsAromatic);
-return this.matchPriv (pattern, search.jmolAtoms, -search.jmolAtoms.length, null, bsAromatic, flags);
-}, "~S,JS.SmilesSearch,~N");
+return this.matchPriv (pattern, search.jmolAtoms, -search.jmolAtoms.length, null, bsAromatic, bsAromatic.isEmpty (), flags, mode);
+}, "~S,JS.SmilesSearch,~N,~N");
 Clazz.defineMethod (c$, "matchPriv", 
- function (pattern, atoms, ac, bsSelected, bsAromatic, flags) {
+ function (pattern, atoms, ac, bsSelected, bsAromatic, doTestAromatic, flags, mode) {
 JS.InvalidSmilesException.clear ();
 try {
-var search = JS.SmilesParser.getMolecule (pattern, ((flags & 2) == 2));
+var isSmarts = ((flags & 2) == 2);
+var search = JS.SmilesParser.getMolecule (pattern, isSmarts);
+if (search.openSMILES && !isSmarts && !search.patternAromatic) JS.SmilesSearch.normalizeAromaticity (search.patternAtoms, bsAromatic, search.flags);
 search.jmolAtoms = atoms;
-if (Clazz.instanceOf (atoms, Array)) search.bioAtoms = atoms;
 search.jmolAtomCount = Math.abs (ac);
 if (ac < 0) search.isSmilesFind = true;
+var is3D = !(Clazz.instanceOf (atoms[0], JS.SmilesAtom));
+if (Clazz.instanceOf (atoms[0], JU.BNode)) search.bioAtoms = atoms;
 search.setSelected (bsSelected);
 search.getSelections ();
 search.bsRequired = null;
-search.setRingData (bsAromatic);
-search.firstMatchOnly = ((flags & 64) == 64);
-search.matchAllAtoms = ((flags & 16) == 16);
-switch (flags & 61440) {
-case 4096:
+if (!doTestAromatic) search.bsAromatic = bsAromatic;
+search.setRingData (null, null, is3D || doTestAromatic);
+search.exitFirstMatch = ((flags & 32) == 32);
+switch (mode) {
+case 1:
 search.asVector = false;
-return search.search (false);
-case 8192:
+return search.search ();
+case 2:
 search.asVector = true;
-var vb = search.search (false);
+var vb = search.search ();
 return vb.toArray ( new Array (vb.size ()));
-case 12288:
+case 3:
 search.getMaps = true;
-var vl = search.search (false);
+var vl = search.search ();
 return vl.toArray (JU.AU.newInt2 (vl.size ()));
 }
 } catch (e) {
@@ -197,14 +202,13 @@ throw e;
 }
 }
 return null;
-}, "~S,~A,~N,JU.BS,JU.BS,~N");
+}, "~S,~A,~N,JU.BS,JU.BS,~B,~N,~N");
 Clazz.overrideMethod (c$, "cleanSmiles", 
 function (smiles) {
 return JS.SmilesParser.cleanPattern (smiles);
 }, "~S");
 Clazz.defineStatics (c$,
-"SMILES_MODE_BITSET", 0x001000,
-"SMILES_MODE_ARRAY", 0x002000,
-"SMILES_MODE_MAP", 0x003000,
-"SMILES_MODE_MASK", 0x00F000);
+"MODE_BITSET", 0x01,
+"MODE_ARRAY", 0x02,
+"MODE_MAP", 0x03);
 });
