@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JS");
-Clazz.load (["J.api.SymmetryInterface"], "JS.Symmetry", ["JU.BS", "$.Lst", "$.M3", "$.M4", "$.P3", "$.V3", "J.api.Interface", "JS.PointGroup", "$.SpaceGroup", "$.SymmetryInfo", "$.SymmetryOperation", "$.UnitCell", "JU.Escape", "$.Logger", "$.SimpleUnitCell"], function () {
+Clazz.load (["J.api.SymmetryInterface"], "JS.Symmetry", ["JU.BS", "$.Lst", "$.P3", "J.api.Interface", "JS.PointGroup", "$.SpaceGroup", "$.SymmetryInfo", "$.SymmetryOperation", "$.UnitCell", "JU.Escape", "$.Logger", "$.SimpleUnitCell"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.pointGroup = null;
 this.spaceGroup = null;
@@ -65,7 +65,7 @@ return this.spaceGroup != null;
 }, "~N,~S,~O");
 Clazz.overrideMethod (c$, "getSpaceGroupInfoStr", 
 function (name, cellInfo) {
-return JS.SpaceGroup.getInfo (name, cellInfo);
+return JS.SpaceGroup.getInfo (this.spaceGroup, name, cellInfo);
 }, "~S,J.api.SymmetryInterface");
 Clazz.overrideMethod (c$, "getLatticeDesignation", 
 function () {
@@ -150,6 +150,14 @@ Clazz.overrideMethod (c$, "getSpaceGroupOperationCount",
 function () {
 return (this.symmetryInfo != null ? this.symmetryInfo.symmetryOperations.length : this.spaceGroup != null && this.spaceGroup.finalOperations != null ? this.spaceGroup.finalOperations.length : 0);
 });
+Clazz.overrideMethod (c$, "getLatticeType", 
+function () {
+return (this.symmetryInfo != null ? this.symmetryInfo.latticeType : this.spaceGroup == null ? "P" : this.spaceGroup.latticeType);
+});
+Clazz.overrideMethod (c$, "getIntTableNumber", 
+function () {
+return (this.symmetryInfo != null ? this.symmetryInfo.intlTableNo : this.spaceGroup == null ? null : this.spaceGroup.intlTableNumber);
+});
 Clazz.overrideMethod (c$, "getCoordinatesAreFractional", 
 function () {
 return this.symmetryInfo == null || this.symmetryInfo.coordinatesAreFractional;
@@ -390,44 +398,7 @@ return JS.SymmetryOperation.fcoord (p);
 }, "JU.T3");
 Clazz.overrideMethod (c$, "getV0abc", 
 function (def) {
-if (this.unitCell == null) return null;
-var m;
-var isRev = false;
-if (Clazz.instanceOf (def, String)) {
-var sdef = def;
-if (sdef.indexOf (";") < 0) sdef += ";0,0,0";
-isRev = sdef.startsWith ("!");
-if (isRev) sdef = sdef.substring (1);
-var symTemp =  new JS.Symmetry ();
-symTemp.setSpaceGroup (false);
-var i = symTemp.addSpaceGroupOperation ("=" + sdef, 0);
-if (i < 0) return null;
-m = symTemp.getSpaceGroupOperation (i);
-(m).doFinalize ();
-} else {
-m = (Clazz.instanceOf (def, JU.M3) ? JU.M4.newMV (def,  new JU.P3 ()) : def);
-}var pts =  new Array (4);
-var pt =  new JU.P3 ();
-var m3 =  new JU.M3 ();
-m.getRotationScale (m3);
-m.getTranslation (pt);
-if (isRev) {
-m3.invert ();
-m3.transpose ();
-m3.rotate (pt);
-pt.scale (-1);
-} else {
-m3.transpose ();
-}this.unitCell.toCartesian (pt, false);
-pts[0] = JU.V3.newV (pt);
-pts[1] = JU.V3.new3 (1, 0, 0);
-pts[2] = JU.V3.new3 (0, 1, 0);
-pts[3] = JU.V3.new3 (0, 0, 1);
-for (var i = 1; i < 4; i++) {
-m3.rotate (pts[i]);
-this.unitCell.toCartesian (pts[i], true);
-}
-return pts;
+return (this.unitCell == null ? null : this.unitCell.getV0abc (def));
 }, "~O");
 Clazz.overrideMethod (c$, "getQuaternionRotation", 
 function (abc) {
@@ -437,16 +408,6 @@ Clazz.overrideMethod (c$, "getFractionalOrigin",
 function () {
 return this.unitCell.getFractionalOrigin ();
 });
-Clazz.overrideMethod (c$, "setAxes", 
-function (scale, axisPoints, fixedOrigin, originPoint) {
-var vertices = this.getUnitCellVerticesNoOffset ();
-var offset = this.getCartesianOffset ();
-if (fixedOrigin == null) originPoint.add2 (offset, vertices[0]);
- else offset = fixedOrigin;
-axisPoints[0].scaleAdd2 (scale, vertices[4], offset);
-axisPoints[1].scaleAdd2 (scale, vertices[2], offset);
-axisPoints[2].scaleAdd2 (scale, vertices[1], offset);
-}, "~N,~A,JU.P3,JU.P3");
 Clazz.overrideMethod (c$, "getState", 
 function (commands) {
 var pt = this.getFractionalOffset ();
@@ -464,4 +425,9 @@ Clazz.overrideMethod (c$, "getIterator",
 function (vwr, atom, atoms, bsAtoms, radius) {
 return (J.api.Interface.getInterface ("JS.UnitCellIterator", vwr, "script")).set (this, atom, atoms, bsAtoms, radius);
 }, "JV.Viewer,JM.Atom,~A,JU.BS,~N");
+Clazz.overrideMethod (c$, "toFromPrimitive", 
+function (toPrimitive, type, oabc) {
+if (this.unitCell == null) this.unitCell = JS.UnitCell.newP (oabc, false);
+return this.unitCell.toFromPrimitive (toPrimitive, type, oabc);
+}, "~B,~S,~A");
 });
