@@ -401,7 +401,9 @@ if (pt2 != null) return this.getSymmetryInfoString (sym, iModel, op, pt, pt2, (i
 var isBio = uc.isBio ();
 var iop = op;
 var centering = null;
-if (xyz == null) {
+if (type == 1073741994) {
+return uc.getLatticeType ();
+}if (xyz == null) {
 var ops = uc.getSymmetryOperations ();
 if (ops == null || op == 0 || Math.abs (op) > ops.length) return (type == 135176 ? "draw ID sym_* delete" : "");
 xyz = ops[iop = Math.abs (op) - 1].xyz;
@@ -446,7 +448,7 @@ case 12289:
 return info[6];
 case 134217751:
 return info[7];
-case 1073741854:
+case 1611272194:
 case 134217750:
 return ((ang == 0) == (type == 134217750) ? info[8] : null);
 case 134217729:
