@@ -101,7 +101,9 @@ s.getRow (i, r);
 sb.append ("[\t");
 for (var j = 0; j < 3; j++) sb.appendI (Clazz.floatToInt (r[j])).append ("\t");
 
-sb.append (JS.SymmetryOperation.twelfthsOf (isCanonical ? (Clazz.floatToInt (r[3]) + 12) % 12 : Clazz.floatToInt (r[3]))).append ("\t]\n");
+var trans = r[3];
+if (trans != Clazz.floatToInt (trans)) trans = 12 * trans;
+sb.append (JS.SymmetryOperation.twelfthsOf (isCanonical ? (Clazz.floatToInt (trans) + 12) % 12 : Clazz.floatToInt (trans))).append ("\t]\n");
 }
 return sb.toString ();
 }, "JU.M4,~B");
@@ -460,12 +462,6 @@ c$.approxF = Clazz.defineMethod (c$, "approxF",
 function (f) {
 return JU.PT.approx (f, 100);
 }, "~N");
-c$.normalizeTranslation = Clazz.defineMethod (c$, "normalizeTranslation", 
-function (operation) {
-operation.m03 = (Clazz.floatToInt (operation.m03) + 12) % 12;
-operation.m13 = (Clazz.floatToInt (operation.m13) + 12) % 12;
-operation.m23 = (Clazz.floatToInt (operation.m23) + 12) % 12;
-}, "JU.M4");
 c$.getXYZFromRsVs = Clazz.defineMethod (c$, "getXYZFromRsVs", 
 function (rs, vs, is12ths) {
 var ra = rs.getArray ();
