@@ -260,7 +260,7 @@ if (pt.z <= 0.02 || pt.z >= 0.98) f /= 2;
 return f;
 }, "JU.P3");
 c$.getReciprocal = Clazz.defineMethod (c$, "getReciprocal", 
-function (abc) {
+function (abc, ret) {
 var rabc =  new Array (4);
 var off = (abc.length == 4 ? 1 : 0);
 rabc[0] = (off == 1 ? JU.P3.newP (abc[0]) :  new JU.P3 ());
@@ -269,23 +269,10 @@ rabc[i + 1] =  new JU.P3 ();
 rabc[i + 1].cross (abc[((i + off) % 3) + off], abc[((i + off + 1) % 3) + off]);
 rabc[i + 1].scale (1 / abc[i + off].dot (rabc[i + 1]));
 }
+if (ret != null) for (var i = 0; i < 4; i++) ret[i] = rabc[i];
+
 return rabc;
-}, "~A");
-c$.transformCubic = Clazz.defineMethod (c$, "transformCubic", 
-function (isPrimitive, type, uc) {
-var offset = uc.length - 3;
-var f = (type.equalsIgnoreCase ("BCC") ? (isPrimitive ?  Clazz.newFloatArray (-1, [.5, .5, -0.5, -0.5, .5, .5, .5, -0.5, .5]) :  Clazz.newFloatArray (-1, [1, 0, 1, 1, 1, 0, 0, 1, 1])) : type.equalsIgnoreCase ("FCC") ? (isPrimitive ?  Clazz.newFloatArray (-1, [.5, .5, 0, 0, .5, .5, .5, 0, .5]) :  Clazz.newFloatArray (-1, [1, -1, 1, 1, 1, -1, -1, 1, 1])) : null);
-if (f == null) return false;
-var b =  new Array (3);
-for (var i = 0, p = 0; i < 3; i++) {
-b[i] =  new JU.P3 ();
-for (var j = offset; j < 3 + offset; j++) b[i].scaleAdd2 (f[p++], uc[j], b[i]);
-
-}
-for (var i = 0; i < 3; i++) uc[i + offset] = b[i];
-
-return true;
-}, "~B,~S,~A");
+}, "~A,~A");
 Clazz.defineStatics (c$,
 "toRadians", 0.017453292,
 "INFO_DIMENSIONS", 6,
