@@ -1,11 +1,11 @@
 var path = ClazzLoader.getClasspathFor ("JV.package");
 path = path.substring (0, path.lastIndexOf ("package.js"));
 ClazzLoader.jarClasspath (path + "StateManager.js", [
-"JV.Connections",
-"$.Connection",
+"JV.Connection",
+"$.Scene",
 "$.StateManager",
-"$.Scene"]);
+"$.Connections"]);
 ClazzLoader.jarClasspath (path + "ActionManager.js", [
-"JV.ActionManager",
-"$.Gesture",
-"$.MotionPoint"]);
+"JV.MotionPoint",
+"$.ActionManager",
+"$.Gesture"]);
