@@ -1,4 +1,4 @@
-(function(K,L,M,u,N,k,D,m,p,q,O,P,t,Q,v,x,r,E,A,y,B,n,z,F,G,w,R,S,T,H,U,V,I,W,X,Y,Z,$,aa,ba,ca,da,ea,fa,ga,ha,ia,ja,ka,la,ma,na,oa,pa,qa,ra,d,g){k("JSV.export");m(["JSV.api.ExportInterface"],"JSV.export.Exporter","JU.Base64 $.PT JSV.common.Annotation $.ExportType $.JSVFileManager $.JSViewer".split(" "),function(){c$=A(JSV["export"],"Exporter",null,JSV.api.ExportInterface);t(c$,function(){});g(c$,"write",function(a,b,c){if(null==b)return this.printPDF(a,null,!1);var e=null,f=null,d,j,s=a.selectedPanel;
+(function(K,L,M,u,N,k,D,m,p,q,O,P,t,Q,v,x,r,E,A,y,B,n,z,F,G,w,R,S,T,H,U,V,I,W,X,Y,Z,$,aa,ba,ca,da,ea,fa,ga,ha,ia,ja,ka,la,ma,na,oa,pa,qa,ra,sa,d,g){k("JSV.export");m(["JSV.api.ExportInterface"],"JSV.export.Exporter","JU.Base64 $.PT JSV.common.Annotation $.ExportType $.JSVFileManager $.JSViewer".split(" "),function(){c$=A(JSV["export"],"Exporter",null,JSV.api.ExportInterface);t(c$,function(){});g(c$,"write",function(a,b,c){if(null==b)return this.printPDF(a,null,!1);var e=null,f=null,d,j,s=a.selectedPanel;
 try{switch(b.size()){default:return"WRITE what?";case 1:f=JU.PT.trimQuotes(b.get(0));f.indexOf(".");if(null==s)return null;d=JSV.common.ExportType.getType(f);switch(d){case JSV.common.ExportType.PDF:case JSV.common.ExportType.PNG:case JSV.common.ExportType.JPG:return this.exportTheSpectrum(a,d,null,null,-1,-1,null,!1);default:a.fileHelper.setFileChooser(d);var h=this.getExportableItems(a,d.equals(JSV.common.ExportType.SOURCE)),g=null==h?-1:a.getOptionFromDialog(h,"Export","Choose a spectrum to export");
 if(-2147483648==g)return null;var C=a.fileHelper.getFile(this.getSuggestedFileName(a,d),s,!0);if(null==C)return null;j=a.getOutputChannel(C.getFullPath(),!1);var k=this.exportSpectrumOrImage(a,d,g,j);k.startsWith("OK")&&a.si.siUpdateRecentMenus(C.getFullPath());return k}case 2:e=b.get(0).toUpperCase(),f=JU.PT.trimQuotes(b.get(1))}var m=f.substring(f.lastIndexOf(".")+1).toUpperCase();m.equals("BASE64")?f=";base64,":m.equals("JDX")?null==e&&(e="XY"):JSV.common.ExportType.isExportMode(m)?e=m:JSV.common.ExportType.isExportMode(e)&&
 (f+="."+e);d=JSV.common.ExportType.getType(e);c&&d===JSV.common.ExportType.SVG&&(d=JSV.common.ExportType.SVGI);j=a.getOutputChannel(f,!1);return this.exportSpectrumOrImage(a,d,-1,j)}catch(n){if(v(n,Exception))return System.out.println(n),null;throw n;}},"JSV.common.JSViewer,JU.Lst,~B");d(c$,"exportSpectrumOrImage",function(a,b,c,e){var f,d=a.pd();if(0>c&&0>(c=d.getCurrentSpectrumIndex()))return"Error exporting spectrum: No spectrum selected";f=d.getSpectrumAt(c);var j=d.getStartingPointIndex(c);c=
@@ -117,4 +117,4 @@ b,c,d,f){this.static_tree=a;this.extra_bits=b;this.extra_base=c;this.elems=d;thi
 9,15,9,271,9,143,9,399,9,79,9,335,9,207,9,463,9,47,9,303,9,175,9,431,9,111,9,367,9,239,9,495,9,31,9,287,9,159,9,415,9,95,9,351,9,223,9,479,9,63,9,319,9,191,9,447,9,127,9,383,9,255,9,511,9,0,7,64,7,32,7,96,7,16,7,80,7,48,7,112,7,8,7,72,7,40,7,104,7,24,7,88,7,56,7,120,7,4,7,68,7,36,7,100,7,20,7,84,7,52,7,116,7,3,8,131,8,67,8,195,8,35,8,163,8,99,8,227,8]),"static_dtree",w(-1,[0,5,16,5,8,5,24,5,4,5,20,5,12,5,28,5,2,5,18,5,10,5,26,5,6,5,22,5,14,5,30,5,1,5,17,5,9,5,25,5,5,5,21,5,13,5,29,5,3,5,19,5,11,5,
 27,5,7,5,23,5]));c$.static_l_desc=c$.prototype.static_l_desc=new JU.StaticTree(JU.StaticTree.static_ltree,JU.Tree.extra_lbits,257,286,15);c$.static_d_desc=c$.prototype.static_d_desc=new JU.StaticTree(JU.StaticTree.static_dtree,JU.Tree.extra_dbits,0,30,15);c$.static_bl_desc=c$.prototype.static_bl_desc=new JU.StaticTree(null,JU.Tree.extra_blbits,0,19,7)});k("JU");z(JU,"Checksum")})(Clazz,Clazz.newLongArray,Clazz.doubleToByte,Clazz.doubleToInt,Clazz.doubleToLong,Clazz.declarePackage,Clazz.instanceOf,
 Clazz.load,Clazz.instantialize,Clazz.decorateAsClass,Clazz.floatToInt,Clazz.floatToLong,Clazz.makeConstructor,Clazz.defineEnumConstant,Clazz.exceptionOf,Clazz.newIntArray,Clazz.defineStatics,Clazz.newFloatArray,Clazz.declareType,Clazz.prepareFields,Clazz.superConstructor,Clazz.newByteArray,Clazz.declareInterface,Clazz.p0p,Clazz.pu$h,Clazz.newShortArray,Clazz.innerTypeInstance,Clazz.isClassDefined,Clazz.prepareCallback,Clazz.newArray,Clazz.castNullAs,Clazz.floatToShort,Clazz.superCall,Clazz.decorateAsType,
-Clazz.newBooleanArray,Clazz.newCharArray,Clazz.implementOf,Clazz.newDoubleArray,Clazz.overrideConstructor,Clazz.clone,Clazz.doubleToShort,Clazz.getInheritedLevel,Clazz.getParamsType,Clazz.isAF,Clazz.isAI,Clazz.isAS,Clazz.isASS,Clazz.isAP,Clazz.isAFloat,Clazz.isAII,Clazz.isAFF,Clazz.isAFFF,Clazz.tryToSearchAndExecute,Clazz.getStackTrace,Clazz.inheritArgs,Clazz.alert,Clazz.defineMethod,Clazz.overrideMethod,Clazz.declareAnonymous,Clazz.cloneFinals);
+Clazz.newBooleanArray,Clazz.newCharArray,Clazz.implementOf,Clazz.newDoubleArray,Clazz.overrideConstructor,Clazz.clone,Clazz.doubleToShort,Clazz.getInheritedLevel,Clazz.getParamsType,Clazz.isAF,Clazz.isAB,Clazz.isAI,Clazz.isAS,Clazz.isASS,Clazz.isAP,Clazz.isAFloat,Clazz.isAII,Clazz.isAFF,Clazz.isAFFF,Clazz.tryToSearchAndExecute,Clazz.getStackTrace,Clazz.inheritArgs,Clazz.alert,Clazz.defineMethod,Clazz.overrideMethod,Clazz.declareAnonymous,Clazz.cloneFinals);
