@@ -120,7 +120,7 @@ return this.evaluateCompare (mp, args);
 case 1228931587:
 case 134217736:
 case 1275203608:
-return this.evaluateConnected (mp, args, tok);
+return this.evaluateConnected (mp, args, tok, op.intValue);
 case 1747587102:
 return this.evaluateUnitCell (mp, args);
 case 134353926:
@@ -269,8 +269,7 @@ ucnew = (u == null ?  Clazz_newArray (-1, [JU.P3.new3 (0, 0, 0), JU.P3.new3 (1,
 }if (ucnew == null) {
 ucnew =  new Array (4);
 if (haveUC) {
-ucnew[0] = JU.P3.newP (JS.SV.ptValue (uc.get (0)));
-for (var i = 1; i < 4; i++) ucnew[i] = JU.P3.newP (JS.SV.ptValue (uc.get (i)));
+for (var i = 0; i < 4; i++) ucnew[i] = JU.P3.newP (JS.SV.ptValue (uc.get (i)));
 
 } else {
 ucnew[0] = JS.SV.ptValue (args[0]);
@@ -289,11 +288,15 @@ break;
 return false;
 }
 }}var op = (ptParam <= lastParam ? args[ptParam].asString () : null);
-var isPrimitive = "primitive".equalsIgnoreCase (op);
-if (isPrimitive || "conventional".equalsIgnoreCase (op)) {
-if (!JU.SimpleUnitCell.transformCubic (isPrimitive, args[++ptParam].asString (), ucnew)) return false;
+var toPrimitive = "primitive".equalsIgnoreCase (op);
+if (toPrimitive || "conventional".equalsIgnoreCase (op)) {
+var stype = (++ptParam > lastParam ? "" : args[ptParam].asString ().toUpperCase ());
+if (stype.equals ("BCC")) stype = "I";
+ else if (stype.length == 0) stype = this.vwr.ms.getSymTemp (false).getSymmetryInfoAtom (this.vwr.ms, this.vwr.bsA (), null, 0, null, null, null, 1073741994);
+if (stype == null || stype.length == 0) return false;
+if (!(u == null ? this.vwr.ms.getSymTemp (true) : u).toFromPrimitive (toPrimitive, stype.charAt (0), ucnew)) return false;
 } else if ("reciprocal".equalsIgnoreCase (op)) {
-ucnew = JU.SimpleUnitCell.getReciprocal (ucnew);
+ucnew = JU.SimpleUnitCell.getReciprocal (ucnew, null);
 }if (scale != 1) for (var i = 1; i < 4; i++) ucnew[i].scale (scale);
 
 return mp.addXObj (ucnew);
@@ -342,14 +345,16 @@ return mp.addXAV (a);
 }, "JS.ScriptMathProcessor,~A,~B");
 Clazz_defineMethod (c$, "evaluateBin", 
  function (mp, args) {
-if (args.length != 3 && args.length != 4) return false;
+if (args.length < 3 || args.length > 5) return false;
 var x1 = mp.getX ();
 var isListf = (x1.tok == 13);
 if (!isListf && x1.tok != 7) return mp.addX (x1);
 var f0 = JS.SV.fValue (args[0]);
 var f1 = JS.SV.fValue (args[1]);
 var df = JS.SV.fValue (args[2]);
-var key = (args.length == 4 ? JS.SV.sValue (args[3]) : null);
+var n = args.length;
+var addBins = (n >= 4 && args[n - 1].tok == 1073742335 && JS.SV.bValue (args[--n]));
+var key = (n >= 4 ? JS.SV.sValue (args[--n]) : null);
 var data;
 var maps = null;
 if (isListf) {
@@ -374,8 +379,7 @@ var nPoints = data.length;
 for (var i = 0; i < nPoints; i++) {
 var v = data[i];
 var bin = Clazz_doubleToInt (Math.floor ((v - f0) / df));
-if (bin < 0) bin = 0;
- else if (bin >= nbins) bin = nbins - 1;
+if (bin < 0 || bin >= nbins) continue;
 array[bin]++;
 if (key != null) {
 var map = maps[i];
@@ -386,7 +390,12 @@ var v2 = v1 + df;
 map.put ("_binMin", JS.SV.newF (bin == 0 ? -3.4028235E38 : v1));
 map.put ("_binMax", JS.SV.newF (bin == nbins - 1 ? 3.4028235E38 : v2));
 }}
-return mp.addXAI (array);
+if (addBins) {
+var lst =  new JU.Lst ();
+for (var i = 0; i < nbins; i++) lst.addLast ( Clazz_newFloatArray (-1, [f0 + df * i, array[i]]));
+
+return mp.addXList (lst);
+}return mp.addXAI (array);
 }, "JS.ScriptMathProcessor,~A");
 Clazz_defineMethod (c$, "evaluateCache", 
  function (mp, args) {
@@ -482,28 +491,29 @@ if (bs1 == null && bs2 == null) return mp.addXStr (this.vwr.getSmilesMatcher ().
 var mf1 = (bs1 == null ? this.vwr.getSmilesMatcher ().getMolecularFormula (smiles1, false) : JU.JmolMolecule.getMolecularFormula (this.vwr.ms.at, bs1, false, null, false));
 var mf2 = (bs2 == null ? this.vwr.getSmilesMatcher ().getMolecularFormula (smiles2, false) : JU.JmolMolecule.getMolecularFormula (this.vwr.ms.at, bs2, false, null, false));
 if (!mf1.equals (mf2)) return mp.addXStr ("NONE");
-if (bs1 != null) smiles1 = this.e.getSmilesExt ().getSmilesMatches ("", null, bs1, null, 1, true, false);
+if (bs1 != null) smiles1 = this.e.getSmilesExt ().getSmilesMatches ("/strict///", null, bs1, null, 1, true, false);
 var check;
 if (bs2 == null) {
 check = (this.vwr.getSmilesMatcher ().areEqual (smiles2, smiles1) > 0);
 } else {
-check = ((this.e.getSmilesExt ().getSmilesMatches (smiles1, null, bs2, null, 1, true, false)).nextSetBit (0) >= 0);
+check = ((this.e.getSmilesExt ().getSmilesMatches ("/strict///" + smiles1, null, bs2, null, 1, true, false)).nextSetBit (0) >= 0);
 }if (!check) {
 var s = smiles1 + smiles2;
 if (s.indexOf ("/") >= 0 || s.indexOf ("\\") >= 0 || s.indexOf ("@") >= 0) {
-if (smiles1.indexOf ("@") >= 0 && (bs2 != null || smiles2.indexOf ("@") >= 0)) {
-smiles1 = "/invertstereo/" + smiles1;
+if (smiles1.indexOf ("@") >= 0 && (bs2 != null || smiles2.indexOf ("@") >= 0) && smiles1.indexOf ("@SP") < 0) {
+var pt = smiles1.toLowerCase ().indexOf ("invertstereo");
+smiles1 = (pt >= 0 ? smiles1.substring (0, pt) + smiles1.substring (pt + 12) : "/invertstereo strict/" + smiles1);
 if (bs2 == null) {
 check = (this.vwr.getSmilesMatcher ().areEqual (smiles1, smiles2) > 0);
 } else {
-check = ((this.e.getSmilesExt ().getSmilesMatches (smiles1, null, bs2, null, 1, true, false)).nextSetBit (0) >= 0);
+check = ((this.e.getSmilesExt ().getSmilesMatches ("/strict/" + smiles1, null, bs2, null, 1, true, false)).nextSetBit (0) >= 0);
 }if (check) return mp.addXStr ("ENANTIOMERS");
 }if (bs2 == null) {
 check = (this.vwr.getSmilesMatcher ().areEqual ("/nostereo/" + smiles2, smiles1) > 0);
 } else {
 var ret = this.e.getSmilesExt ().getSmilesMatches ("/nostereo/" + smiles1, null, bs2, null, 1, true, false);
 check = ((ret).nextSetBit (0) >= 0);
-}if (check) return mp.addXStr ("DIASTERIOMERS");
+}if (check) return mp.addXStr ("DIASTEREOMERS");
 }return mp.addXStr ("CONSTITUTIONAL ISOMERS");
 }if (bs1 == null || bs2 == null) return mp.addXStr ("IDENTICAL");
 stddev = this.e.getSmilesExt ().getSmilesCorrelation (bs1, bs2, smiles1, null, null, null, null, false, null, null, false, 1);
@@ -528,7 +538,7 @@ if (!isMap && !isSmiles || hMaps && isPolyhedron) return false;
 pattern = "/noaromatic" + (allMaps || bestMap ? "/" : " nostereo/") + this.e.getSmilesExt ().getSmilesMatches ((hMaps ? "H" : ""), null, bs1, null, 1, true, false);
 } else {
 allMaps = true;
-}stddev = this.e.getSmilesExt ().getSmilesCorrelation (bs1, bs2, pattern, ptsA, ptsB, m, null, isMap, null, null, bestMap, (isSmiles ? 1 : 2) | (!allMaps && !bestMap ? 64 : 0));
+}stddev = this.e.getSmilesExt ().getSmilesCorrelation (bs1, bs2, pattern, ptsA, ptsB, m, null, isMap, null, null, bestMap, (isSmiles ? 1 : 2) | (!allMaps && !bestMap ? 32 : 0));
 if (isMap) {
 var nAtoms = ptsA.size ();
 if (nAtoms == 0) return mp.addXStr ("");
@@ -566,7 +576,7 @@ throw ex;
 }
 }, "JS.ScriptMathProcessor,~A");
 Clazz_defineMethod (c$, "evaluateConnected", 
- function (mp, args, tok) {
+ function (mp, args, tok, intValue) {
 if (args.length > 5) return false;
 var min = -2147483648;
 var max = 2147483647;
@@ -590,9 +600,10 @@ case 4:
 smiles = JS.SV.sValue (args[0]);
 break;
 }
-}var data =  Clazz_newArray (-1, [Integer.$valueOf (nv), smiles, null]);
-this.vwr.shm.getShapePropertyData (21, "centers", data);
-return mp.addXBs (data[2] == null ?  new JU.BS () : data[2]);
+}if (intValue == 1275203608) atoms1 = JS.SV.getBitSet (mp.getX (), true);
+var data =  Clazz_newArray (-1, [Integer.$valueOf (nv), smiles, atoms1]);
+if (!this.vwr.shm.getShapePropertyData (21, "getCenters", data)) data[1] = null;
+return mp.addXBs (data[1] == null ?  new JU.BS () : data[1]);
 case 1228931587:
 var x1 = mp.getX ();
 if (x1.tok != 10 || args.length != 1 || args[0].tok != 10) return false;
@@ -655,7 +666,7 @@ var bsBonds =  new JU.BS ();
 this.vwr.makeConnections (fmin, fmax, order, 1086324745, atoms1, atoms2, bsBonds, isBonds, false, 0);
 return mp.addX (JS.SV.newV (10, JM.BondSet.newBS (bsBonds, this.vwr.ms.getAtomIndices (this.vwr.ms.getAtoms (1677721602, bsBonds)))));
 }return mp.addXBs (this.vwr.ms.getAtomsConnected (min, max, order, atoms1));
-}, "JS.ScriptMathProcessor,~A,~N");
+}, "JS.ScriptMathProcessor,~A,~N,~N");
 Clazz_defineMethod (c$, "evaluateContact", 
  function (mp, args) {
 if (args.length < 1 || args.length > 3) return false;
@@ -828,11 +839,9 @@ return (data == null ? false : mp.addXObj (JU.Escape.escapeHelical (type, tok, p
 }var bs = (Clazz_instanceOf (args[0].value, JU.BS) ? args[0].value : this.vwr.ms.getAtoms (1094715412,  new Integer (args[0].asInt ())));
 switch (tok) {
 case 134217751:
-return mp.addXObj (this.getHelixData (bs, 134217751));
-case 1073741854:
-return mp.addXObj (this.getHelixData (bs, 1073741854));
+case 1611272194:
 case 1665140738:
-return mp.addXObj (this.getHelixData (bs, 1665140738));
+return mp.addXObj (this.getHelixData (bs, tok));
 case 134217729:
 return mp.addXFloat ((this.getHelixData (bs, 134217729)).floatValue ());
 case 135176:
@@ -859,7 +868,20 @@ var sFind = (isEmpty ? "" : JS.SV.sValue (args[0]));
 var flags = (args.length > 1 && args[1].tok != 1073742335 && args[1].tok != 1073742334 ? JS.SV.sValue (args[1]) : "");
 var isSequence = !isList && sFind.equalsIgnoreCase ("SEQUENCE");
 var isSeq = !isList && sFind.equalsIgnoreCase ("SEQ");
-var isSmiles = !isList && sFind.equalsIgnoreCase ("SMILES");
+if (sFind.toUpperCase ().startsWith ("SMILES/")) {
+if (!sFind.endsWith ("/")) sFind += "/";
+var s = sFind.substring (6) + "//";
+if (JV.JC.isSmilesCanonical (s)) {
+flags = "SMILES";
+sFind = "CHEMICAL";
+} else {
+sFind = "SMILES";
+flags = s + flags;
+}} else if (sFind.toUpperCase ().startsWith ("SMARTS/")) {
+if (!sFind.endsWith ("/")) sFind += "/";
+flags = sFind.substring (6) + (flags.length == 0 ? "//" : flags);
+sFind = "SMARTS";
+}var isSmiles = !isList && sFind.equalsIgnoreCase ("SMILES");
 var isSMARTS = !isList && sFind.equalsIgnoreCase ("SMARTS");
 var isChemical = !isList && sFind.equalsIgnoreCase ("CHEMICAL");
 var isMF = !isList && sFind.equalsIgnoreCase ("MF");
@@ -868,9 +890,8 @@ var argLast = (args.length > 0 ? args[args.length - 1] : JS.SV.vF);
 var isON = !isList && (argLast.tok == 1073742335);
 try {
 if (isChemical) {
-var data = (x1.tok == 10 ? this.vwr.getSmiles (x1.value) : JS.SV.sValue (x1));
-data = data.length == 0 ? "" : this.vwr.getChemicalInfo (data, args.length > 1 ? JS.T.getTokenFromName (flags.toLowerCase ()) : null);
-if (data.endsWith ("\n")) data = data.substring (0, data.length - 1);
+var data = (x1.tok == 10 ? this.vwr.getOpenSmiles (x1.value) : JS.SV.sValue (x1));
+data = (data.length == 0 ? "" : this.vwr.getChemicalInfo (data, flags.toLowerCase ())).trim ();
 if (data.startsWith ("InChI")) data = JU.PT.rep (JU.PT.rep (data, "InChI=", ""), "InChIKey=", "");
 return mp.addXStr (data);
 }if (isSmiles || isSMARTS || x1.tok == 10) {
@@ -896,6 +917,7 @@ case 3:
 asMap = JS.SV.bValue (args[2]);
 break;
 }
+var justOne = (!asMap && (!allMappings || !isSMARTS));
 try {
 ret = this.e.getSmilesExt ().getSmilesMatches (pattern, smiles, null, null, isSMARTS ? 2 : 1, !asMap, !allMappings);
 } catch (e) {
@@ -905,7 +927,7 @@ return mp.addXInt (-1);
 throw e;
 }
 }
-if (!asMap && (!allMappings || !isSMARTS)) {
+if (justOne) {
 var len = (ret).length;
 return mp.addXInt (!allMappings && len > 0 ? 1 : len);
 }}break;
@@ -915,14 +937,15 @@ if (isMF || isCF) return mp.addXStr (JU.JmolMolecule.getMolecularFormula (this.v
 if (isSequence || isSeq) {
 var isHH = (argLast.asString ().equalsIgnoreCase ("H"));
 isAll = new Boolean (isAll | isHH).valueOf ();
-return mp.addXStr (this.vwr.getSmilesOpt (x1.value, -1, -1, (isAll ? 69632 | 73728 | (isHH ? 90112 : 0) : 0) | (isSeq ? 327680 : 65536)));
-}if (isSmiles || isSMARTS) sFind = (args.length > 1 && args[1].tok == 10 ? this.vwr.getSmilesOpt (args[1].value, 0, 0, 0) : flags);
+return mp.addXStr (this.vwr.getSmilesOpt (x1.value, -1, -1, (isAll ? 3145728 | 5242880 | (isHH ? 9437184 : 0) : 0) | (isSeq ? 34603008 : 1048576), null));
+}if (isSmiles || isSMARTS) sFind = (args.length > 1 && args[1].tok == 10 ? this.vwr.getSmilesOpt (args[1].value, 0, 0, 0, null) : flags);
+flags = flags.toUpperCase ();
 var bsMatch3D = bs2;
 if (asBonds) {
-var map = this.vwr.getSmilesMatcher ().getCorrelationMaps (sFind, this.vwr.ms.at, this.vwr.ms.ac, x1.value, (isSmiles ? 1 : 2) | 64);
+var map = this.vwr.getSmilesMatcher ().getCorrelationMaps (sFind, this.vwr.ms.at, this.vwr.ms.ac, x1.value, (isSmiles ? 1 : 2) | 32);
 ret = (map.length > 0 ? this.vwr.ms.getDihedralMap (map[0]) :  Clazz_newIntArray (0, 0));
 } else {
-var smilesFlags = (isSmiles ? 1 : 2) | (isON && sFind.length == 0 ? 204800 : 0);
+var smilesFlags = (isSmiles ? (flags.indexOf ("OPEN") >= 0 ? 5 : 1) : 2) | (isON && sFind.length == 0 ? 22020096 : 0);
 ret = this.e.getSmilesExt ().getSmilesMatches (sFind, null, x1.value, bsMatch3D, smilesFlags, !isON, false);
 }break;
 }
@@ -2050,7 +2073,7 @@ tok = 1073741982;
 } else if (desc.equalsIgnoreCase ("translation")) {
 tok = 1073742178;
 } else if (desc.equalsIgnoreCase ("axis")) {
-tok = 1073741854;
+tok = 1611272194;
 } else if (desc.equalsIgnoreCase ("plane")) {
 tok = 134217750;
 } else if (desc.equalsIgnoreCase ("angle")) {
