@@ -12,7 +12,7 @@ m&&0<m.length&&e.append("  frame title ").append(JU.PT.esc(m)).append(";\n"),c&&
 ";\n").appendSB(e);c=!1;if(null!=f.unitCells){g=!1;for(h=0;h<k;h++)m=f.getUnitCell(h),null!=m&&(e.setLength(0),m.getState(e)&&(c=!0,d.append("  frame ").append(f.getModelNumberDotted(h)).appendSB(e).append(";\n")),g=(new Boolean(g|0<=this.vwr.ms.getLastVibrationVector(h,1275072532))).valueOf());c&&this.vwr.shm.loadShape(33);this.getShapeState(d,b,33);if(g){b=new java.util.Hashtable;for(h=k;0<=--h;)if(0<=(k=this.vwr.ms.getLastVibrationVector(h,1275072532)))for(e=j[h].firstAtomIndex;e<=k;e++)c=f.getModulation(e),
 null!=c&&JU.BSUtil.setMapBitSet(b,e,e,c.getState());d.append(this.getCommands(b,null,"select"))}}d.append("  set fontScaling "+this.vwr.getBoolean(603979845)+";\n")}null!=a&&d.append("\n}\n\n");return d.toString()},"JU.SB,~B,~B");l(c$,"getShapeState",function(a,b,c){var d=this.vwr.shm.shapes;if(null!=d){var e,f,g;2147483647==c?(c=0,g=37):g=c+1;for(;c<g;++c)null!=(f=d[c])&&((b||9<=c&&16>c)&&null!=(e=f.getShapeState())&&1<e.length)&&a.append(e);a.append("  select *;\n")}},"JU.SB,~B,~N");l(c$,"getWindowState",
 function(a,b,c){var d=this.vwr.g,e=new JU.SB;null!=a&&(a.append("  initialize;\n  set refreshing false;\n  _setWindowState;\n"),e.append("\nfunction _setWindowState() {\n"));0!=b&&e.append("# preferredWidthHeight ").appendI(b).append(" ").appendI(c).append(";\n");e.append("# width ").appendI(0==b?this.vwr.getScreenWidth():b).append(";\n# height ").appendI(0==c?this.vwr.getScreenHeight():c).append(";\n");this.app(e,"stateVersion = "+JV.JC.versionInt);this.app(e,"background "+JU.Escape.escapeColor(d.objColors[0]));
-for(b=1;8>b;b++)0!=d.objColors[b]&&this.app(e,JV.StateManager.getObjectNameFromId(b)+'Color = "'+JU.Escape.escapeColor(d.objColors[b])+'"');null!=d.backgroundImageFileName&&this.app(e,"background IMAGE "+(d.backgroundImageFileName.startsWith(";base64,")?"":"/*file*/")+JU.PT.esc(d.backgroundImageFileName));e.append(this.getLightingState(!1));null!=a&&e.append("}\n\n");return e.toString()},"JU.SB,~N,~N");n(c$,"getLightingState",function(a){var b=new JU.SB,c=this.vwr.gdata;this.app(b,"set ambientPercent "+
+for(b=1;7>b;b++)0!=d.objColors[b]&&this.app(e,JV.StateManager.getObjectNameFromId(b)+'Color = "'+JU.Escape.escapeColor(d.objColors[b])+'"');null!=d.backgroundImageFileName&&this.app(e,"background IMAGE "+(d.backgroundImageFileName.startsWith(";base64,")?"":"/*file*/")+JU.PT.esc(d.backgroundImageFileName));e.append(this.getLightingState(!1));null!=a&&e.append("}\n\n");return e.toString()},"JU.SB,~N,~N");n(c$,"getLightingState",function(a){var b=new JU.SB,c=this.vwr.gdata;this.app(b,"set ambientPercent "+
 c.getAmbientPercent());this.app(b,"set diffusePercent "+c.getDiffusePercent());this.app(b,"set specular "+c.getSpecular());this.app(b,"set specularPercent "+c.getSpecularPercent());this.app(b,"set specularPower "+c.getSpecularPower());var d=c.getSpecularExponent(),e=c.getPhongExponent();this.app(b,Math.pow(2,d)==e?"set specularExponent "+d:"set phongExponent "+e);this.app(b,"set celShading "+c.getCel());this.app(b,"set celShadingPower "+c.getCelPower());this.app(b,"set zShadePower "+this.vwr.g.zShadePower);
 a&&this.getZshadeState(b,this.vwr.tm,!0);return b.toString()},"~B");l(c$,"getFileState",function(a){var b=new JU.SB;null!=a&&(a.append("  _setFileState;\n"),b.append("function _setFileState() {\n\n"));0>b.indexOf("append")&&this.vwr.getModelSetFileName().equals("zapped")&&b.append("  zap;\n");this.appendLoadStates(b);null!=a&&b.append("\n}\n\n");return b.toString()},"JU.SB");l(c$,"appendLoadStates",function(a){var b=this.vwr.ligandModelSet;if(null!=b)for(var c,b=b.keySet().iterator();b.hasNext()&&
 ((c=b.next())||1);){var d=this.vwr.ligandModels.get(c+"_data");null!=d&&a.append("  ").append(JU.Escape.encapsulateData("ligand_"+c,d.trim()+"\n",0));d=this.vwr.ligandModels.get(c+"_file");null!=d&&a.append("  ").append(JU.Escape.encapsulateData("file_"+c,d.trim()+"\n",0))}var b=new JU.SB,d=this.vwr.ms,e=d.am,f=d.mc;for(c=0;c<f;c++)if(!d.isJmolDataFrameForModel(c)&&!d.isTrajectorySubFrame(c)){var g=e[c],j=b.indexOf(g.loadState);(0>j||j!=b.lastIndexOf(g.loadState))&&b.append(e[c].loadState);e[c].isModelKit?
@@ -34,8 +34,8 @@ a.vibrationOn&&this.app(c,"set vibrationPeriod "+a.vibrationPeriod+";vibration o
 try{null!=b.zSlabPoint&&this.app(a,"set zSlab "+JU.Escape.eP(b.zSlabPoint))}catch(d){if(!s(d,Exception))throw d;}},"JU.SB,JV.TransformManager,~B");n(c$,"getSpinState",function(){var a=this.vwr.tm,b="  set spinX "+p(a.spinX)+"; set spinY "+p(a.spinY)+"; set spinZ "+p(a.spinZ)+"; set spinFps "+p(a.spinFps)+";";Float.isNaN(a.navFps)||(b+="  set navX "+p(a.navX)+"; set navY "+p(a.navY)+"; set navZ "+p(a.navZ)+"; set navFps "+p(a.navFps)+";");a.navOn&&(b+=" navigation on;");if(!a.spinOn)return b;var c=
 a.isSpinSelected?"\n  select "+JU.Escape.eBS(this.vwr.bsA())+";\n  rotateSelected":"\n ";if(a.isSpinInternal){var d=JU.P3.newP(a.internalRotationCenter);d.sub(a.rotationAxis);b+=c+" spin "+a.rotationRate+" "+JU.Escape.eP(a.internalRotationCenter)+" "+JU.Escape.eP(d)}else b=a.isSpinFixed?b+(c+" spin axisangle "+JU.Escape.eP(a.rotationAxis)+" "+a.rotationRate):b+" spin on";return b+";"},"~B");n(c$,"getCommands",function(a,b,c){var d=new JU.SB;a=this.getCommands2(a,d,null,c);null!=b&&this.getCommands2(b,
 d,a,"select");return d.toString()},"java.util.Map,java.util.Map,~S");l(c$,"getCommands2",function(a,b,c,d){if(null==a)return"";var e;for(a=a.entrySet().iterator();a.hasNext()&&((e=a.next())||1);){var f=e.getKey(),g=JU.Escape.eBS(e.getValue());5>g.length||(g=d+" "+g,g.equals(c)||this.app(b,g),c=g,0!=f.indexOf("-")&&this.app(b,f))}return c},"java.util.Map,JU.SB,~S,~S");l(c$,"app",function(a,b){0!=b.length&&a.append("  ").append(b).append(";\n")},"JU.SB,~S");l(c$,"addBs",function(a,b,c){null==c||0==
-c.length()||this.app(a,b+JU.Escape.eBS(c))},"JU.SB,~S,JU.BS");n(c$,"getFontState",function(a,b){var c=JV.StateManager.getObjectIdFromName(a.equalsIgnoreCase("axes")?"axis":a);if(0>c)return"";var d=this.vwr.getObjectMad(c),c=(new JU.SB).append("\n");this.app(c,a+(0==d?" off":1==d?" on":-1==d?" dotted":20>d?" "+d:" "+d/2E3));if(3>c.length())return"";d=J.shape.Shape.getFontCommand(a,b);0<d.length&&(d="  "+d+";\n");return c+d},"~S,javajs.awt.Font");n(c$,"getFontLineShapeState",function(a,b,c){var d=0<=
-a.indexOf(" off"),e=new JU.SB;e.append(a);for(a=0;4>a;a++)null!=c[a]&&this.appendTickInfo(b,e,c[a]);d&&e.append("  "+b+" off;\n");return e.toString()},"~S,~S,~A");l(c$,"appendTickInfo",function(a,b,c){b.append("  ");b.append(a);JV.StateCreator.addTickInfo(b,c,!1);b.append(";\n")},"~S,JU.SB,JM.TickInfo");c$.addTickInfo=l(c$,"addTickInfo",function(a,b,c){a.append(" ticks ").append(b.type).append(" ").append(JU.Escape.eP(b.ticks));var d=null!=b.scale&&Float.isNaN(b.scale.x);d&&a.append(" UNITCELL");
+c.length()||this.app(a,b+JU.Escape.eBS(c))},"JU.SB,~S,JU.BS");n(c$,"getFontState",function(a,b){var c=JV.StateManager.getObjectIdFromName(a.equalsIgnoreCase("axes")?"axis":a);if(0>c)return"";var d=this.vwr.getObjectMad10(c),c=(new JU.SB).append("\n");this.app(c,a+(0==d?" off":1==d?" on":-1==d?" dotted":20>d?" "+d:" "+d/2E4));if(3>c.length())return"";d=J.shape.Shape.getFontCommand(a,b);0<d.length&&(d="  "+d+";\n");return c+d},"~S,javajs.awt.Font");n(c$,"getFontLineShapeState",function(a,b,c){var d=
+0<=a.indexOf(" off"),e=new JU.SB;e.append(a);for(a=0;4>a;a++)null!=c[a]&&this.appendTickInfo(b,e,c[a]);d&&e.append("  "+b+" off;\n");return e.toString()},"~S,~S,~A");l(c$,"appendTickInfo",function(a,b,c){b.append("  ");b.append(a);JV.StateCreator.addTickInfo(b,c,!1);b.append(";\n")},"~S,JU.SB,JM.TickInfo");c$.addTickInfo=l(c$,"addTickInfo",function(a,b,c){a.append(" ticks ").append(b.type).append(" ").append(JU.Escape.eP(b.ticks));var d=null!=b.scale&&Float.isNaN(b.scale.x);d&&a.append(" UNITCELL");
 null!=b.tickLabelFormats&&a.append(" format ").append(JU.Escape.eAS(b.tickLabelFormats,!1));!d&&null!=b.scale&&a.append(" scale ").append(JU.Escape.eP(b.scale));c&&(!Float.isNaN(b.first)&&0!=b.first)&&a.append(" first ").appendF(b.first);null!=b.reference&&a.append(" point ").append(JU.Escape.eP(b.reference))},"JU.SB,JM.TickInfo,~B");n(c$,"getMeasurementState",function(a,b,c,d,e){var f=new JU.SB;this.app(f,"measures delete");for(var g=0;g<c;g++){var j=b.get(g),k=j.count,m=(new JU.SB).append("measure");
 null!=j.thisID&&m.append(" ID ").append(JU.PT.esc(j.thisID));0!=j.mad&&m.append(" radius ").appendF(null==j.thisID||0<j.mad?j.mad/2E3:0);0!=j.colix&&m.append(" color ").append(JU.Escape.escapeColor(JU.C.getArgb(j.colix)));null!=j.text&&(m.append(" font ").append(j.text.font.getInfo()),null!=j.text.pymolOffset&&m.append(" offset ").append(JU.Escape.eAF(j.text.pymolOffset)));var h=j.tickInfo;null!=h&&JV.StateCreator.addTickInfo(m,h,!0);for(h=1;h<=k;h++)m.append(" ").append(j.getLabel(h,!0,!0));m.append("; # "+
 a.getInfoAsString(g));this.app(f,m.toString())}this.app(f,"select *; set measures "+this.vwr.g.measureDistanceUnits);this.app(f,J.shape.Shape.getFontCommand("measures",d));d=0;k=new java.util.Hashtable;m=JU.BS.newN(c);for(g=0;g<c;g++)j=b.get(g),j.isHidden&&(d++,m.set(g)),null!=a.bsColixSet&&a.bsColixSet.get(g)&&JU.BSUtil.setMapBitSet(k,g,g,J.shape.Shape.getColorCommandUnk("measure",j.colix,a.translucentAllowed)),null!=j.strFormat&&JU.BSUtil.setMapBitSet(k,g,g,"measure "+JU.PT.esc(j.strFormat));if(0<
