@@ -5,6 +5,10 @@
 
 // see JSmolApi.js for public user-interface. All these are private functions
 
+// BH 3/23/2016 1:21:39 PM adding http://files.rcsb.org/view/%FILE.pdb as default RCSB site for "="
+
+// BH 2/29/2016 3:59:55 PM broken cursor_wait image path when Info.j2sPath is not "j2s"
+// BH 2/19/2016 10:32:18 AM typo fixed for makeLiveImage
 // BH 2/14/2016 12:31:02 PM fixed local reader not disappearing after script call
 // BH 2/14/2016 12:30:41 PM Info.appletLoadingImage: "j2s/img/JSmol_spinner.gif", 
    // can be set to "none" or some other image; see Jmol._hideLoadingSpinner(applet)
@@ -155,7 +159,7 @@ Jmol = (function(document) {
 		}
 	};
 	var j = {
-		_version: "$Date: 2016-02-14 19:46:51 -0600 (Sun, 14 Feb 2016) $", // svn.keywords:lastUpdated
+		_version: "$Date: 2016-03-24 16:58:21 -0500 (Thu, 24 Mar 2016) $", // svn.keywords:lastUpdated
 		_alertNoBinary: true,
 		// this url is used to Google Analytics tracking of Jmol use. You may remove it or modify it if you wish. 
 		_allowedJmolSize: [25, 2048, 300],   // min, max, default (pixels)
@@ -187,6 +191,7 @@ Jmol = (function(document) {
         // null here means no conversion necessary 
 				"cactus.nci.nih.gov": null,
         "rruff.geo.arizona.edu": null, 
+        "files.rcsb.org": null, 
 				"www.rcsb.org": null,
 				"cdn.rcsb.org": null,
 				"ftp.wwpdb.org": null,
@@ -197,7 +202,7 @@ Jmol = (function(document) {
 				"http://www.nmrdb.org/tools/jmol/predict.php":null,
 				"$": "http://cactus.nci.nih.gov/chemical/structure/%FILENCI/file?format=sdf&get3d=True",
 				"$$": "http://cactus.nci.nih.gov/chemical/structure/%FILENCI/file?format=sdf",
-				"=": "http://www.rcsb.org/pdb/files/%FILE.pdb",
+				"=": "http://files.rcsb.org/view/%FILE.pdb",
 				"*": "http://www.ebi.ac.uk/pdbe/entry-files/download/%FILE.cif",
 				"==": "http://www.rcsb.org/pdb/files/ligand/%FILE.cif",
 				":": "http://pubchem.ncbi.nlm.nih.gov/rest/pug/compound/%FILE/SDF?record_type=3d"
@@ -1183,13 +1188,13 @@ Jmol = (function(document) {
 			var img = ""; 
 			if (applet._coverImage){
 				var more = " onclick=\"Jmol.coverApplet(ID, false)\" title=\"" + (applet._coverTitle) + "\"";
-				var play = "<image id=\"ID_coverclickgo\" src=\"" + applet._makeLiveImg + "\" style=\"width:25px;height:25px;position:absolute;bottom:10px;left:10px;"
+				var play = "<image id=\"ID_coverclickgo\" src=\"" + applet._makeLiveImage + "\" style=\"width:25px;height:25px;position:absolute;bottom:10px;left:10px;"
 					+ "z-index:" + Jmol._getZ(applet, "coverImage")+";opacity:0.5;\"" + more + " />"  
 				img = "<div id=\"ID_coverdiv\" style=\"background-color:red;z-index:" + Jmol._getZ(applet, "coverImage")+";width:100%;height:100%;display:inline;position:absolute;top:0px;left:0px\"><image id=\"ID_coverimage\" src=\""
 				 + applet._coverImage + "\" style=\"width:100%;height:100%\"" + more + "/>" + play + "</div>";
 			}
       
-      var wait = (applet._isJava ? "" : "<image id=\"ID_waitimage\" src=\"j2s/img/cursor_wait.gif\" style=\"display:none;position:absolute;bottom:10px;left:10px;"
+      var wait = (applet._isJava ? "" : "<image id=\"ID_waitimage\" src=\"" + applet._j2sPath + "/img/cursor_wait.gif\" style=\"display:none;position:absolute;bottom:10px;left:10px;"
 					+ "z-index:" + Jmol._getZ(applet, "coverImage")+";\" />");  
 
 			var css = Jmol._appletCssText.replace(/\'/g,'"');
@@ -1352,7 +1357,7 @@ Jmol = (function(document) {
 		Jmol._j2sPath && (Info.j2sPath = Jmol._j2sPath);
 		obj._j2sPath = Info.j2sPath;
 		obj._coverImage = Info.coverImage;
-    obj._makeLiveImage = Info.makeLiveImage || Info._j2sPath + "/img/play_make_live.jpg";
+    obj._makeLiveImage = Info.makeLiveImage || Info.j2sPath + "/img/play_make_live.jpg";
 		obj._isCovered = !!obj._coverImage; 
 		obj._deferApplet = Info.deferApplet || obj._isCovered && obj._isJava; // must do this if covered in Java
 		obj._deferUncover = Info.deferUncover && !obj._isJava; // can't do this with Java
